@@ -24,17 +24,15 @@ namespace Rosegarden
 
 // Time constants used with ChannelInterval
 // @author Tom Breton (Tehom)
+// @author Ted Felix
 // NB: We cannot use the RealTime constants here lest we fall victim to
 //     C++'s unpredictable static init order.
-// See RealTime::beforeZeroTime
-const RealTime ChannelInterval::m_beforeEarliestTime(-1,0);
-// See RealTime::zeroTime
-const RealTime ChannelInterval::m_earliestTime(0,0);
-// See RealTime::beforeMaxTime
+// We can't assume all events are > ZeroTime, there are rare
+// exceptions.  These used to correspond to constants in RealTime.cpp.
+const RealTime ChannelInterval::m_beforeEarliestTime(std::numeric_limits<int>::min(),0);
+const RealTime ChannelInterval::m_earliestTime(std::numeric_limits<int>::min()-1,0);
 const RealTime ChannelInterval::m_latestTime(std::numeric_limits<int>::max(),0);
-// See RealTime::maxTime
 const RealTime ChannelInterval::m_afterLatestTime(std::numeric_limits<int>::max(),999999999);
 
 }
 
-
