@@ -29,6 +29,7 @@
 #include <cmath>
 #include <typeinfo>
 #include <iterator>
+#include <map>
 #include <limits.h>
 
 #include <sstream>
@@ -175,7 +176,7 @@ int Composition::m_defaultNbBars = 100;
 
 Composition::Composition() :
     m_solo(false),   // default is not soloing
-    m_selectedTrack(0),
+    m_selectedTrackId(0),
     m_timeSigSegment(TimeSignature::EventType),
     m_tempoSegment(TempoEventType),
     m_barPositionsNeedCalculating(true),
@@ -224,6 +225,7 @@ Composition::addSegment(Segment *segment)
 
     if (res != end()) {
         updateRefreshStatuses();
+        distributeVerses();
 	notifySegmentAdded(segment);
     }
     
@@ -252,6 +254,7 @@ Composition::deleteSegment(Composition::iterator i)
     p->setComposition(0);
 
     m_segments.erase(i);
+    distributeVerses();
     notifySegmentRemoved(p);
     delete p;
 
@@ -274,6 +277,7 @@ Composition::detachSegment(Segment *segment)
     bool res = weakDetachSegment(segment);
 
     if (res) {
+        distributeVerses();
         notifySegmentRemoved(segment);
         updateRefreshStatuses();
     }
@@ -623,7 +627,7 @@ Composition::clear()
     m_startMarker = 0;
     m_endMarker = getBarRange(m_defaultNbBars).first;
     m_solo = false;
-    m_selectedTrack = 0;
+    m_selectedTrackId = 0;
     updateRefreshStatuses();
 }
 
@@ -1672,9 +1676,9 @@ void Composition::resetTrackIdAndPosition(TrackId oldId, TrackId newId,
 }
 #endif
 
-void Composition::setSelectedTrack(TrackId track)
+void Composition::setSelectedTrack(TrackId trackId)
 {
-    m_selectedTrack = track;
+    m_selectedTrackId = trackId;
     notifySoloChanged();
 }
 
@@ -1755,23 +1759,22 @@ bool Composition::detachTrack(Rosegarden::Track *track)
 
 void Composition::checkSelectedAndRecordTracks()
 {
-    // reset m_selectedTrack and m_recordTrack to the next valid track id
+    // reset m_selectedTrackId and m_recordTrack to the next valid track id
     // if the track they point to has been deleted
 
-    if (m_tracks.find(m_selectedTrack) == m_tracks.end()) {
+    if (m_tracks.find(m_selectedTrackId) == m_tracks.end()) {
 
-        m_selectedTrack = getClosestValidTrackId(m_selectedTrack);
-	notifySoloChanged();
+        m_selectedTrackId = getClosestValidTrackId(m_selectedTrackId);
+        notifySoloChanged();
         
     }
 
     for (recordtrackcontainer::iterator i = m_recordTracks.begin();
-	 i != m_recordTracks.end(); ++i) {
-	if (m_tracks.find(*i) == m_tracks.end()) {
-	    m_recordTracks.erase(i);
-	}
+         i != m_recordTracks.end(); ++i) {
+        if (m_tracks.find(*i) == m_tracks.end()) {
+            m_recordTracks.erase(i);
+        }
     }
-
 }
 
 TrackId
@@ -1878,7 +1881,7 @@ std::string Composition::toXmlString()
     if (m_solo)
         composition << "\" solo=\"" << m_solo;
 
-    composition << "\" selected=\"" << m_selectedTrack;
+    composition << "\" selected=\"" << m_selectedTrackId;
     composition << "\" playmetronome=\"" << m_playMetronome;
     composition << "\" recordmetronome=\"" << m_recordMetronome;
     composition << "\" nexttriggerid=\"" << m_nextTriggerSegmentId;
@@ -1967,7 +1970,7 @@ Composition::clearTracks()
 {
     trackiterator it = m_tracks.begin();
 
-    for (; it != m_tracks.end(); it++)
+    for (; it != m_tracks.end(); ++it)
         delete ((*it).second);
 
     m_tracks.erase(m_tracks.begin(), m_tracks.end());
@@ -1978,7 +1981,7 @@ Composition::getTrackByPosition(int position) const
 {
     trackconstiterator it = m_tracks.begin();
 
-    for (; it != m_tracks.end(); it++)
+    for (; it != m_tracks.end(); ++it)
     {
         if ((*it).second->getPosition() == position)
             return (*it).second;
@@ -2009,7 +2012,7 @@ Composition::getNewTrackId() const
 
     trackconstiterator it = m_tracks.begin();
 
-    for (; it != m_tracks.end(); it++)
+    for (; it != m_tracks.end(); ++it)
     {
         if ((*it).second->getId() >= highWater)
             highWater = (*it).second->getId() + 1;
@@ -2253,6 +2256,15 @@ Composition::notifyTracksAdded(std::vector<TrackId> trackIds) const
     }
 }
 
+void
+Composition::notifyTrackSelectionChanged(TrackId t) const
+{
+    for (ObserverSet::const_iterator i = m_observers.begin();
+         i != m_observers.end(); ++i) {
+        (*i)->trackSelectionChanged(this, t);
+    }
+}
+
 void
 Composition::notifyMetronomeChanged() const
 {
@@ -2374,6 +2386,43 @@ Composition::setGeneralColourMap(Rosegarden::ColourMap &newmap)
     updateRefreshStatuses();
 }
 
+void
+Composition::distributeVerses()
+{
+    typedef std::map<int, segmentcontainer> SegmentMap;
+    SegmentMap tracks;
+    SegmentMap repeats;
+
+    // Sort segments by track ID
+    for (iterator i = begin(); i != end(); ++i) {
+        Segment* s = *i;
+        tracks[s->getTrack()].insert(s);
+    }
+
+    // Work track after track
+    for (SegmentMap::iterator i = tracks.begin(); i != tracks.end(); ++i) {
+
+        // Reset all verse indexes and look for repeated segments
+        repeats.clear();
+        for (segmentcontainer::iterator j = i->second.begin(); j != i->second.end(); ++j) {
+             Segment* s = *j;
+             s->setVerse(0);
+             if (s->isPlainlyLinked()) {
+                 repeats[s->getLinker()->getSegmentLinkerId()].insert(s);
+            }
+        }
+
+        // Set verse indexes where needed
+        for (SegmentMap::iterator j = repeats.begin(); j != repeats.end(); ++j) {
+            int verse = 0;
+            for (segmentcontainer::iterator k = j->second.begin(); k != j->second.end(); ++k) {
+                Segment* s = *k;
+                s->setVerse(verse++);
+            }
+        }
+    }
+}
+
 void
 Composition::dump(std::ostream& out, bool) const
 {
@@ -2387,6 +2436,7 @@ Composition::dump(std::ostream& out, bool) const
             << " - repeating : " << s->isRepeating()
             << " - track id : " << s->getTrack()
             << " - label : " << s->getLabel()
+//            << " - verse : " << s->getVerse()
             << endl;
         
     }
