@@ -140,12 +140,14 @@ public:
     bool isTrackRecording(TrackId track) const;
 
     /// Get the selected (solo) track.
+    /// rename: getSelectedTrackId()
     /// @see setSelectedTrack()
     /// @see setSolo()
-    TrackId getSelectedTrack() const { return m_selectedTrack; }
+    TrackId getSelectedTrack() const { return m_selectedTrackId; }
     /// Set the selected (solo) track.
+    /// rename: setSelectedTrackId()
     /// @see getSelectedTrack()
-    void setSelectedTrack(TrackId track);
+    void setSelectedTrack(TrackId trackId);
 
     /// Are we soloing the selected track?
     /// @see setSolo()
@@ -861,7 +863,7 @@ public:
      * See the various other "notify*" functions.
      *
      * These functions have been made public in the interests of improving
-     * performance.  There are at lease two main approaches to sending change
+     * performance.  There are at least two main approaches to sending change
      * notifications to observers.  The first is to have each modifier
      * function (e.g. deleteTrack()) send the change notification.  The second
      * is to make the change notification functions public and let the code
@@ -884,6 +886,16 @@ public:
      * @see notifyTracksAdded()
      */
     void notifyTracksDeleted(std::vector<TrackId> trackIds) const;
+    /// Call when the selected track is changed.
+    /**
+     * @see setSelectedTrack()
+     * @see notifyTracksAdded()
+     */
+    void notifyTrackSelectionChanged(TrackId) const;
+
+    //////
+    // LYRICS WITH REPEATED SEGMENTS
+    void distributeVerses();
 
     //////
     // DEBUG FACILITIES
@@ -939,7 +951,8 @@ protected:
     // Are we soloing and if so which Track?
     //
     bool m_solo;
-    TrackId m_selectedTrack;
+
+    TrackId m_selectedTrackId;
 
     /**
      * This is a bit like a segment, but can only contain one sort of
@@ -1164,6 +1177,13 @@ public:
      */
     virtual void endMarkerTimeChanged(const Composition *, bool /* shorten */) { }
 
+    /**
+     * Called when a different track is selected.  This can happen when
+     * the user clicks on a track label, or presses the up/down arrow keys
+     * to change which track is currently selected.
+     */
+    virtual void trackSelectionChanged(const Composition *, TrackId) { }
+
     /**
      * Called when a track is changed (instrument id, muted status...)
      */
