@@ -46,7 +46,7 @@ Segment::Segment(SegmentType segmentType, timeT startTime) :
     m_startTime(startTime),
     m_endMarkerTime(0),
     m_endTime(startTime),
-    m_track(0),
+    m_trackId(0),
     m_type(segmentType),
     m_colourIndex(0),
     m_id(0),
@@ -74,7 +74,9 @@ Segment::Segment(SegmentType segmentType, timeT startTime) :
     m_fadeInTime(Rosegarden::RealTime::zeroTime),
     m_fadeOutTime(Rosegarden::RealTime::zeroTime),
     m_segmentLinker(0),
-    m_isTmp(0)
+    m_isTmp(0),
+    m_verseCount(-1),   // -1 => computation needed
+    m_verse(0)
 {
 }
 
@@ -86,7 +88,7 @@ Segment::Segment(const Segment &segment):
     m_endMarkerTime(segment.m_endMarkerTime ?
                     new timeT(*segment.m_endMarkerTime) : 0),
     m_endTime(segment.getEndTime()),
-    m_track(segment.getTrack()),
+    m_trackId(segment.getTrack()),
     m_type(segment.getType()),
     m_label(segment.getLabel()),
     m_colourIndex(segment.getColourIndex()),
@@ -116,7 +118,9 @@ Segment::Segment(const Segment &segment):
     m_fadeInTime(segment.getFadeInTime()),
     m_fadeOutTime(segment.getFadeOutTime()),
     m_segmentLinker(0), //yes, this is intentional. clone() handles this
-    m_isTmp(segment.isTmp())
+    m_isTmp(segment.isTmp()),
+    m_verseCount(-1),   // -1 => computation needed
+    m_verse(0)   // Needs a global recomputation on the whole composition 
 {
     for (const_iterator it = segment.begin();
          it != segment.end(); ++it) {
@@ -263,12 +267,13 @@ Segment::setTrack(TrackId id)
 {
     Composition *c = m_composition;
     if (c) c->weakDetachSegment(this); // sets m_composition to 0
-    TrackId oldTrack = m_track;
-    m_track = id;
+    TrackId oldTrackId = m_trackId;
+    m_trackId = id;
     if (c) {
         c->weakAddSegment(this);
         c->updateRefreshStatuses();
-        c->notifySegmentTrackChanged(this, oldTrack, id);
+        c->distributeVerses();
+        c->notifySegmentTrackChanged(this, oldTrackId, id);
     }
 }
 
@@ -1402,6 +1407,7 @@ Segment::notifyStartChanged(timeT newTime)
         (*i)->startChanged(this, newTime);
     }
     if (m_composition) {
+        m_composition->distributeVerses();
         m_composition->notifySegmentStartChanged(this, newTime);
     }
 }
@@ -1521,6 +1527,44 @@ Segment::getEventRuler(const std::string &type, int controllerValue)
 }
 
 
+int
+Segment::getVerseCount()
+{
+    if (m_verseCount == -1) countVerses();
+    return m_verseCount;
+}
+
+int
+Segment::getVerseWrapped()
+{
+    int count = getVerseCount();
+    return count ? getVerse() % count : 0;
+}
+
+// Following code moved from LyricEditDialog.cpp
+void
+Segment::countVerses()
+{
+    m_verseCount = 0;
+
+    for (iterator i = begin(); isBeforeEndMarker(i); ++i) {
+
+        if ((*i)->isa(Text::EventType)) {
+
+            std::string textType;
+            if ((*i)->get<String>(Text::TextTypePropertyName, textType) &&
+                textType == Text::Lyric) {
+
+                long verse = 0;
+                (*i)->get<Int>(Text::LyricVersePropertyName, verse);
+
+                if (verse >= m_verseCount) m_verseCount = verse + 1;
+            }
+        }
+    }
+}
+
+
 SegmentHelper::~SegmentHelper() { }
 
 
