@@ -14,8 +14,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _SEGMENT_H_
-#define _SEGMENT_H_
+#ifndef RG_SEGMENT_H
+#define RG_SEGMENT_H
 
 #include <set>
 #include <list>
@@ -31,6 +31,7 @@
 namespace Rosegarden
 {
 
+/// A refresh flag with a time range.
 class SegmentRefreshStatus : public RefreshStatus
 {
 public:
@@ -46,7 +47,14 @@ protected:
     timeT m_to;
 };
 
+class SegmentObserver;
+class Quantizer;
+class BasicQuantizer;
+class Composition;
+class SegmentLinker;
+class BasicCommand;
 
+/// Container of Event objects.
 /**
  * Segment is the container for a set of Events that are all played on
  * the same track.  Each event has an absolute starting time,
@@ -65,14 +73,6 @@ protected:
  *
  * The Segment owns the Events its items are pointing at.
  */
-
-class SegmentObserver;
-class Quantizer;
-class BasicQuantizer;
-class Composition;
-class SegmentLinker;
-class BasicCommand;
-
 class Segment : public QObject, public std::multiset<Event*, Event::EventCmp>
 {
   Q_OBJECT
@@ -145,15 +145,17 @@ public:
         }
     }
 
+    // Get the track ID this Segment is associated with.
     /**
-     * Get the track number this Segment is associated with.
+     * rename: getTrackId()
      */
-    TrackId getTrack() const { return m_track; }
+    TrackId getTrack() const { return m_trackId; }
 
+    /// Set the track ID this Segment is associated with.
     /**
-     * Set the track number this Segment is associated with.
+     * rename: setTrackId()
      */
-    void setTrack(TrackId i);
+    void setTrack(TrackId trackId);
 
     // label
     //
@@ -351,24 +353,16 @@ public:
     //
     // EVENT MANIPULATION
 
-    /**
-     * Inserts a single Event
-     */
+    /// Insert a single Event
     iterator insert(Event *e);
 
-    /**
-     * Erases a single Event
-     */
+    /// Erase a single Event
     void erase(iterator pos);
 
-    /**
-     * Erases a set of Events
-     */
+    /// Erase a set of Events
     void erase(iterator from, iterator to);
 
-    /**
-     * Clear the segment.
-     */
+    /// Clear the segment.
     void clear() { erase(begin(), end()); }
 
     /**
@@ -585,6 +579,41 @@ public:
     int getTranspose() const { return m_transpose; }
     void setTranspose(int transpose);
 
+    /**
+     * Return the number of verses in the lyrics
+     * (call countVerses() when needed)
+     */
+    int getVerseCount();
+    
+    /**
+     * (Re)compute the internally remembered verse count
+     */
+    void countVerses();
+
+    /**
+     * Return the verse index of lyrics associated with the segment if
+     * this one is unfolded in the notation editor.
+     * (ie the verse which have to be written under the staff among all the
+     * verses included as text of lyrics inside the segment)
+     */
+    int getVerse() const { return m_verse; }
+
+    /**
+     * Return the verse index of lyrics associated with the segment if
+     * this one is unfolded in the notation editor.
+     * As getVerse(), but return again the first verses when going beyond
+     * the total verses count.
+     */
+    int getVerseWrapped();
+
+    /**
+     * Used to set the value returned by getVerse().
+     * Should only be called from a method recomputing verse for all
+     * the segments in composition (or for the temporary segments in
+     * a notation editor)
+     */
+    void setVerse (int verse) { m_verse = verse; }
+
 
 
     //////
@@ -805,7 +834,7 @@ private:
 
     void updateEndTime();       // called after erase of item at end
 
-    TrackId m_track;
+    TrackId m_trackId;
     SegmentType m_type;         // identifies Segment type
     std::string m_label;        // segment label
 
@@ -886,25 +915,30 @@ private:
 
     // Audio autofading
     //
-    bool                  m_autoFade;
+    bool      m_autoFade;
     RealTime  m_fadeInTime;
     RealTime  m_fadeOutTime;
 
+    // Linked segments
     SegmentLinker *m_segmentLinker;
     LinkTransposeParams m_linkTransposeParams;
-    bool m_isTmp;   // Mark a segment (usually a link) as temporary
+    bool m_isTmp;      // Mark a segment (usually a link) as temporary
+    int m_verseCount;  // -1 means not computed still
+    int m_verse;       // Used to distribute lyrics among repeated segments
 };
 
 typedef std::multiset<Segment*, Segment::SegmentCmp> segmentcontainer;
 
+/// Base class interface for Segment notifications.
+/**
+ * See Segment::addObserver() and Segment::m_observers.
+ */
 class SegmentObserver
 {
 public:
     virtual ~SegmentObserver() {}
 
-    /**
-     * Called after the event has been added to the segment
-     */
+    /// Called after an event has been added to the segment.
     virtual void eventAdded(const Segment *, Event *) { }
 
     /**
@@ -919,22 +953,16 @@ public:
      */
     virtual void appearanceChanged(const Segment *) { }
 
-    /**
-     * Called after a change that affects the start time of the segment
-     */
+    /// Called after a change that affects the start time of the segment.
     virtual void startChanged(const Segment *, timeT) { }
 
+    /// Called after the segment's end marker time has been changed.
     /**
-     * Called after the segment's end marker time has been
-     * changed
-     *
      * @param shorten true if the marker change shortens the segment's duration
      */
     virtual void endMarkerTimeChanged(const Segment *, bool /*shorten*/) { }
 
-    /**
-     * Called after a change of the segment transposition
-     */
+    /// Called after a change of the segment transposition.
     virtual void transposeChanged(const Segment *, int /*transpose*/) { }
 
     /**
@@ -945,9 +973,6 @@ public:
 };
 
 
-
-// an abstract base
-
 class SegmentHelper
 {
 protected:
