@@ -18,7 +18,7 @@
 #include "SegmentNotationHelper.h"
 #include "base/BaseProperties.h"
 #include "misc/Debug.h"
-#include <limits>
+
 
 namespace Rosegarden {
 
@@ -141,7 +141,7 @@ EventSelection::eraseThisEvent(Event *e)
 	interval = m_segmentEvents.equal_range(e);
 
     for (eventcontainer::iterator it = interval.first;
-         it != interval.second; it++) {
+         it != interval.second; ++it) {
 
         if (*it == e) {
 
@@ -186,12 +186,15 @@ EventSelection::addRemoveEvent(Event *e, EventFuncPtr insertEraseFn)
     // ARE one unit, and having selections treat them that way solves a lot of
     // usability problems.
     //
+    // We have to recheck against end() because insertEraseFn can
+    // change that.
     // looking AHEAD:
-    if (e->has(BaseProperties::TIED_FORWARD)) {
+    if (e->has(BaseProperties::TIED_FORWARD) &&
+        (baseSegmentItr != m_originalSegment.end())) {
 
         long oldPitch = 0;
         if (e->has(BaseProperties::PITCH)) e->get<Int>(BaseProperties::PITCH, oldPitch);
-        
+
         // Set iterator to the next element in container after baseSegmentItr;
         Segment::const_iterator si = baseSegmentItr;
         ++si;
@@ -382,49 +385,6 @@ EventSelection::getTotalNotationDuration() const
     return end - start;
 }
 
-
-// Return the average value of an integer-valued property for events
-// in the selection.
-int
-EventSelection::getAverageProperty(PropertyName property) const
-{
-    float total = 0;
-    int count = 0;
-    for (eventcontainer::iterator i = getSegmentEvents().begin();
-         i != getSegmentEvents().end();
-         ++i) {
-        if ((*i)->has(property)) {
-            total += (*i)->get<Int>(property);
-            ++count;
-        }
-    }
-
-    if (count > 0) { return (total / count) + 0.5; }
-    else { return 0; }
-}
-
-
-// Return the maximum and minimum values of an integer-valued property
-// for events in the selection.
-std::pair<int,int>
-EventSelection::getMinMaxProperty(PropertyName property) const
-{
-    // Start with values such that anything we find will supersede
-    // them.
-    int min = std::numeric_limits<int>::max(),
-        max = std::numeric_limits<int>::min();
-    for (eventcontainer::iterator i = getSegmentEvents().begin();
-         i != getSegmentEvents().end();
-         ++i) {
-        if ((*i)->has(property)) {
-            int value = (*i)->get<Int>(property);
-            if (max < value) { max = value; }
-            if (value < min) { min = value; }
-        }
-    }
-    return std::pair<int,int>(min,max);
-}
-
 EventSelection::RangeList
 EventSelection::getRanges() const
 {
