@@ -32,7 +32,7 @@ class RingingParameterPattern : public ParameterPattern
     // Make as many sliders as we need.  EventParameterDialog will
     // truncate or pad as needed.
     virtual SliderSpecVector
-        getSliderSpec(const Situation *situation) const;
+        getSliderSpec(const SelectionSituation *situation) const;
 
     // Set the properties of events from begin to end.
     virtual void
