@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2011 the Rosegarden development team.
+    Copyright 2000-2012 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -52,14 +52,18 @@ AddTracksCommand::~AddTracksCommand()
 
 void AddTracksCommand::execute()
 {
-    // Re-attach tracks
+    // Re-attach tracks (redo)
     //
     if (m_detached) {
 
+        std::vector<TrackId> trackIds;
+
         for (size_t i = 0; i < m_newTracks.size(); i++) {
             m_composition->addTrack(m_newTracks[i]);
+            trackIds.push_back(m_newTracks[i]->getId());
         }
 
+        // Adjust the track positions.
         for (TrackPositionMap::iterator i = m_oldPositions.begin();
              i != m_oldPositions.end(); ++i) {
 
@@ -68,9 +72,15 @@ void AddTracksCommand::execute()
             if (track) track->setPosition(newPosition);
         }
 
+        m_composition->notifyTracksAdded(trackIds);
+
+        m_detached = false;
+
         return;
     }
 
+    // Adjust the track positions
+
     int highPosition = 0;
 
     for (Composition::trackiterator it = m_composition->getTracks().begin();
@@ -98,6 +108,10 @@ void AddTracksCommand::execute()
         }
     }
 
+    // Add the tracks
+
+    std::vector<TrackId> trackIds;
+
     for (unsigned int i = 0; i < m_nbNewTracks; ++i) {
 
         TrackId trackId = m_composition->getNewTrackId();
@@ -107,16 +121,24 @@ void AddTracksCommand::execute()
         track->setInstrument(m_instrumentId);
 
         m_composition->addTrack(track);
+        trackIds.push_back(trackId);
         m_newTracks.push_back(track);
     }
+
+    m_composition->notifyTracksAdded(trackIds);
 }
 
 void AddTracksCommand::unexecute()
 {
+    std::vector<TrackId> trackIds;
+
+    // Detach the tracks
     for (size_t i = 0; i < m_newTracks.size(); i++) {
         m_composition->detachTrack(m_newTracks[i]);
+        trackIds.push_back(m_newTracks[i]->getId());
     }
 
+    // Adjust the positions
     for (TrackPositionMap::iterator i = m_oldPositions.begin();
          i != m_oldPositions.end(); ++i) {
 
@@ -124,6 +146,8 @@ void AddTracksCommand::unexecute()
         if (track) track->setPosition(i->second);
     }
 
+    m_composition->notifyTracksDeleted(trackIds);
+
     m_detached = true;
 }
 
