@@ -134,7 +134,7 @@ FitToBeatsCommand::initialise(Segment *s)
         RealTime nextRealTime = finalRealTime;
         // nextTempo is unused, it will be used if we make ramped
         // tempi.
-        tempoT   nextTempo    = defaultTempo;
+        /* tempoT   nextTempo    = defaultTempo; */
 
 
         // Treat all the other beats.
@@ -152,7 +152,7 @@ FitToBeatsCommand::initialise(Segment *s)
             // Step
             nextBeatTime = timeNow;
             nextRealTime = realTimeNow;
-            nextTempo    = tempo;
+            /* nextTempo    = tempo; */
             ++i;
         }
     }
@@ -172,7 +172,7 @@ FitToBeatsCommand::initialise(Segment *s)
     segmentcontainer &origSegments = m_composition->getSegments();
     for (Composition::iterator i = origSegments.begin();
          i != origSegments.end();
-         i++) {
+         ++i) {
         Segment * const oldSegment = *i;
 
         // We'd prefer to just make a segment with no events that's
