@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2011 the Rosegarden development team.
+    Copyright 2000-2012 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -66,12 +66,6 @@ private:
     static void
         getCurrentTempi(Composition &composition, TempoMap &Tempos);
 
-    static double
-        beatRealTimeToBpm(RealTime &realTime);
-    static tempoT
-        beatTimeRatioToTempo(RealTime &realTime,
-                             timeT beatTime, tempoT rampTo);
-
     Composition *m_composition;
 
     segmentcontainer m_oldSegments;
