@@ -41,7 +41,7 @@ SegmentRepeatToCopyCommand::~SegmentRepeatToCopyCommand()
         std::vector<Segment*>::iterator it =
             m_newSegments.begin();
 
-        for (; it != m_newSegments.end(); it++)
+        for (; it != m_newSegments.end(); ++it)
             delete (*it);
     }
 }
@@ -49,7 +49,7 @@ SegmentRepeatToCopyCommand::~SegmentRepeatToCopyCommand()
 void
 SegmentRepeatToCopyCommand::execute()
 {
-    if (m_newSegments.size() == 0) {
+    if (m_newSegments.empty()) {
         timeT newStartTime = m_segment->getEndMarkerTime();
         timeT newDuration =
             m_segment->getEndMarkerTime() - m_segment->getStartTime();
@@ -76,7 +76,7 @@ SegmentRepeatToCopyCommand::execute()
         std::vector<Segment*>::iterator it =
             m_newSegments.begin();
 
-        for (; it != m_newSegments.end(); it++)
+        for (; it != m_newSegments.end(); ++it)
             m_composition->addSegment(*it);
     }
     m_segment->setRepeating(false);
@@ -89,7 +89,7 @@ SegmentRepeatToCopyCommand::unexecute()
     std::vector<Segment*>::iterator it =
         m_newSegments.begin();
 
-    for (; it != m_newSegments.end(); it++)
+    for (; it != m_newSegments.end(); ++it)
         m_composition->detachSegment(*it);
 
     m_detached = true;
