@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2011 the Rosegarden development team.
+    Copyright 2000-2012 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -112,8 +112,6 @@ public:
     bool error(const QXmlParseException& exception);
     bool fatalError(const QXmlParseException& exception);
 
-    /// Returns true if any channels were remapped
-    bool channelsWereRemapped() const { return m_remappedChannels; }
 
 protected:
 
@@ -191,7 +189,6 @@ protected:
     bool                              m_cancelled;
     bool                              m_skipAllAudio;
     bool                              m_hasActiveAudio;
-    bool                              m_remappedChannels;
 };
 
 
