@@ -42,6 +42,7 @@
 
 
 class QObject;
+class QString;
 
 
 namespace Rosegarden
@@ -86,8 +87,18 @@ public:
     LilyPondExporter(NotationView *parent, RosegardenDocument *, std::string fileName);
     ~LilyPondExporter();
 
+   /**
+    * Write the LilyPond score into the specified file.
+    * @return true if successfull, false otherwise.
+    */
     bool write();
 
+   /**
+    * @return an explanatory message on what goes wrong on the last
+    * call to write().
+    */
+    QString getMessage() { return m_warningMessage; }
+
 protected:
     RosegardenMainViewWidget *m_view;
     NotationView *m_notationView;
@@ -209,6 +220,7 @@ private:
     static const unsigned int EXPORT_NONMUTED_TRACKS = 1;
     static const unsigned int EXPORT_SELECTED_TRACK = 2;
     static const unsigned int EXPORT_SELECTED_SEGMENTS = 3;
+    static const unsigned int EXPORT_EDITED_SEGMENTS = 4;
 
     bool m_exportBeams;
     bool m_exportStaffGroup;
@@ -244,8 +256,8 @@ private:
     };
 
     bool m_voltaBar;
-
     bool m_cancelAccidentals;
+    QString m_warningMessage;
 
     std::pair<int,int> fractionSum(std::pair<int,int> x,std::pair<int,int> y) {
 	std::pair<int,int> z(
@@ -288,4 +300,3 @@ private:
 }
 
 #endif
-
