@@ -56,7 +56,7 @@ class LilyPondSegmentsContext
 
 public:
     /**
-     * Create an empty context
+     * Create an empty segment context
      */
     LilyPondSegmentsContext(LilyPondExporter *exporter, Composition *composition);
 
@@ -67,6 +67,11 @@ public:
      */
     void addSegment(Segment *segment);
 
+    /**
+     * Return true if the segment context is empty
+     */
+    bool containsNoSegment();
+
     /**
      * Walk through all segments, find the repeating ones and compute
      * their start times in the LilyPond score assuming they are synchronous.
