@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2011 the Rosegarden development team.
+    Copyright 2000-2012 the Rosegarden development team.
 
     This file is Copyright 2002
         Hans Kieserman      <hkieserman@mail.com>
@@ -38,6 +38,7 @@ class RosegardenDocument;
 class Key;
 class Clef;
 class AccidentalTable;
+class Instrument;
 
 /**
  *   The global structure of this exporter (MusicXmlExporter::write()) is
@@ -118,11 +119,14 @@ public:
      * A simple structure to store some MIDI information required to include
      * the MIDI support in MusicXML file.
      */
-    typedef struct midi_instrument {
-        int         channel;
-        int         program;
-        int         unpitched;
-    } MidiInstrument;
+    struct MidiInstrument
+    {
+      MidiInstrument(void) {};
+      MidiInstrument(Instrument * instrument, int pitch);
+      int         channel;
+      int         program;
+      int         unpitched;
+    };
     typedef std::map<std::string, MidiInstrument> InstrumentMap;
 
     /**
