@@ -489,16 +489,18 @@ RosegardenMainViewWidget::createNotationView(std::vector<Segment *> segmentsToEd
             notationView, SLOT(slotCompositionStateUpdate()));
 
     // Encourage the notation view window to open to the same
-    // interval as the current segment view
-    if (m_trackEditor->getCompositionView()->horizontalScrollBar()->value() > 1) { // don't scroll unless we need to
-        // first find the time at the center of the visible segment canvas
-        int centerX = (int)(m_trackEditor->getCompositionView()->contentsX() +
-                            m_trackEditor->getCompositionView()->visibleWidth() / 2);
-        timeT centerSegmentView = m_trackEditor->getRulerScale()->getTimeForX(centerX);
-        // then scroll the notation view to that time, "localized" for the current segment
-//!!!        notationView->scrollToTime(centerSegmentView);
-//!!!        notationView->updateView();
-    }
+    // interval as the current segment view.  Since scrollToTime is
+    // commented out (what bug?), it made no sense to leave the
+    // support code in.
+//     if (m_trackEditor->getCompositionView()->horizontalScrollBar()->value() > 1) { // don't scroll unless we need to
+//         // first find the time at the center of the visible segment canvas
+//         int centerX = (int)(m_trackEditor->getCompositionView()->contentsX() +
+//                             m_trackEditor->getCompositionView()->visibleWidth() / 2);
+//         timeT centerSegmentView = m_trackEditor->getRulerScale()->getTimeForX(centerX);
+//         // then scroll the notation view to that time, "localized" for the current segment
+// //!!!        notationView->scrollToTime(centerSegmentView);
+// //!!!        notationView->updateView();
+//     }
 
     return notationView;
 }
@@ -662,16 +664,18 @@ RosegardenMainViewWidget::createPitchTrackerView(std::vector<Segment *> segments
             pitchTrackerView, SLOT(slotCompositionStateUpdate()));
 
     // Encourage the notation view window to open to the same
-    // interval as the current segment view
-    if (m_trackEditor->getCompositionView()->horizontalScrollBar()->value() > 1) { // don't scroll unless we need to
-        // first find the time at the center of the visible segment canvas
-        int centerX = (int)(m_trackEditor->getCompositionView()->contentsX() +
-                            m_trackEditor->getCompositionView()->visibleWidth() / 2);
-        timeT centerSegmentView = m_trackEditor->getRulerScale()->getTimeForX(centerX);
-        // then scroll the notation view to that time, "localized" for the current segment
-//!!!        pitchTrackerView->scrollToTime(centerSegmentView);
-//!!!        pitchTrackerView->updateView();
-    }
+    // interval as the current segment view.  Since scrollToTime is
+    // commented out (what bug?), it made no sense to leave the
+    // support code in.
+//     if (m_trackEditor->getCompositionView()->horizontalScrollBar()->value() > 1) { // don't scroll unless we need to
+//         // first find the time at the center of the visible segment canvas
+//         int centerX = (int)(m_trackEditor->getCompositionView()->contentsX() +
+//                             m_trackEditor->getCompositionView()->visibleWidth() / 2);
+//         timeT centerSegmentView = m_trackEditor->getRulerScale()->getTimeForX(centerX);
+//         // then scroll the notation view to that time, "localized" for the current segment
+// //!!!        pitchTrackerView->scrollToTime(centerSegmentView);
+// //!!!        pitchTrackerView->updateView();
+//     }
 
     return pitchTrackerView;
 }
@@ -865,17 +869,19 @@ RosegardenMainViewWidget::createMatrixView(std::vector<Segment *> segmentsToEdit
             matrixView, SLOT(slotCompositionStateUpdate()));
 
     // Encourage the matrix view window to open to the same
-    // interval as the current segment view
-    if (m_trackEditor->getCompositionView()->horizontalScrollBar()->value() > 1) { // don't scroll unless we need to
-        // first find the time at the center of the visible segment canvas
-        int centerX = (int)(m_trackEditor->getCompositionView()->contentsX());
-        // Seems to work better for matrix view to scroll to left side
-        // + m_trackEditor->getCompositionView()->visibleWidth() / 2);
-        timeT centerSegmentView = m_trackEditor->getRulerScale()->getTimeForX(centerX);
-        // then scroll the view to that time, "localized" for the current segment
-//!!!        matrixView->scrollToTime(centerSegmentView);
-//!!!        matrixView->updateView();
-    }
+    // interval as the current segment view.   Since scrollToTime is
+    // commented out (what bug?), it made no sense to leave the
+    // support code in.
+//     if (m_trackEditor->getCompositionView()->horizontalScrollBar()->value() > 1) { // don't scroll unless we need to
+//         // first find the time at the center of the visible segment canvas
+//         int centerX = (int)(m_trackEditor->getCompositionView()->contentsX());
+//         // Seems to work better for matrix view to scroll to left side
+//         // + m_trackEditor->getCompositionView()->visibleWidth() / 2);
+//         timeT centerSegmentView = m_trackEditor->getRulerScale()->getTimeForX(centerX);
+//         // then scroll the view to that time, "localized" for the current segment
+// //!!!        matrixView->scrollToTime(centerSegmentView);
+// //!!!        matrixView->updateView();
+//     }
 
     return matrixView;
 }
@@ -1108,7 +1114,7 @@ void RosegardenMainViewWidget::slotSelectTrackSegments(int trackId)
         // (all the other segments will be deselected)
         for (Composition::iterator i =
                     getDocument()->getComposition().begin();
-                i != getDocument()->getComposition().end(); i++) {
+                i != getDocument()->getComposition().end(); ++i) {
             if (((int)(*i)->getTrack()) == trackId)
                 segments.insert(*i);
         }
@@ -1128,7 +1134,7 @@ void RosegardenMainViewWidget::slotSelectTrackSegments(int trackId)
         bool noSegSelected = true;
         for (Composition::iterator i =
                   getDocument()->getComposition().begin();
-              i != getDocument()->getComposition().end(); i++) {
+              i != getDocument()->getComposition().end(); ++i) {
             if (((int)(*i)->getTrack()) == trackId) {
                 if (segments.count(*i)) {
                     // Segment *i is selected
@@ -1143,7 +1149,7 @@ void RosegardenMainViewWidget::slotSelectTrackSegments(int trackId)
             // Deselect all selected segments on this track
             for (Composition::iterator i =
                      getDocument()->getComposition().begin();
-                 i != getDocument()->getComposition().end(); i++) {
+                 i != getDocument()->getComposition().end(); ++i) {
                 if (((int)(*i)->getTrack()) == trackId) {
                     if (segments.count(*i)) {
                         // Segment *i is selected
@@ -1159,7 +1165,7 @@ void RosegardenMainViewWidget::slotSelectTrackSegments(int trackId)
             // Select all segments on this track
             for (Composition::iterator i =
                      getDocument()->getComposition().begin();
-                 i != getDocument()->getComposition().end(); i++) {
+                 i != getDocument()->getComposition().end(); ++i) {
                 if (((int)(*i)->getTrack()) == trackId) {
                     segments.insert(*i);
                 }
@@ -1169,9 +1175,10 @@ void RosegardenMainViewWidget::slotSelectTrackSegments(int trackId)
     }
     
 
-    // Show the selection on the track buttons.  Find the position.
-    //
-    m_trackEditor->getTrackButtons()->selectTrack(track->getPosition());
+    // This is now handled via Composition::notifyTrackSelectionChanged()
+    //m_trackEditor->getTrackButtons()->selectTrack(track->getPosition());
+
+    // Make sure the track is visible.
     m_trackEditor->slotScrollToTrack(track->getPosition());
 
     // Store the selected Track in the Composition
@@ -1291,9 +1298,9 @@ void RosegardenMainViewWidget::slotUpdateInstrumentParameterBox(int id)
 {
     Studio &studio = getDocument()->getStudio();
     Instrument *instrument = studio.getInstrumentById(id);
-    Composition &comp = getDocument()->getComposition();
+    // Composition &comp = getDocument()->getComposition();
 
-    Track *track = comp.getTrackById(comp.getSelectedTrack());
+    // Track *track = comp.getTrackById(comp.getSelectedTrack());
 
     // Reset the instrument
     //
@@ -1770,7 +1777,7 @@ RosegardenMainViewWidget::slotDroppedNewAudio(QString audioDesc)
 
     std::cerr << "RosegardenMainViewWidget::slotDroppedNewAudio: url " << url << ", trackId " << trackId << ", time " << time << std::endl;
 
-    RosegardenMainWindow *mainWindow = RosegardenMainWindow::self();
+    // RosegardenMainWindow *mainWindow = RosegardenMainWindow::self();
     AudioFileManager &aFM = getDocument()->getAudioFileManager();
 
     AudioFileId audioFileId = 0;
@@ -1786,8 +1793,13 @@ RosegardenMainViewWidget::slotDroppedNewAudio(QString audioDesc)
     }
 
     // from qt4-doc : " don't use a (modal) QProgressDialog inside a paintEvent() !"
-    ProgressDialog *progressDlg = new ProgressDialog(tr("Adding audio file..."),
-                               (QWidget*)this);
+
+    //cc 20120508: because ProgressDialog has WA_DeleteOnClose set, it
+    // is destroyed if the user closes it during event processing --
+    // use a QPointer to avoid dereferencing it afterwards
+    QPointer<ProgressDialog> progressDlg =
+        new ProgressDialog(tr("Adding audio file..."),
+                           (QWidget*)this);
     progressDlg->setIndeterminate(true);
     
     // warning: pointer &progressDlg becomes invalid, if function quits.
@@ -1806,19 +1818,19 @@ RosegardenMainViewWidget::slotDroppedNewAudio(QString audioDesc)
         audioFileId = aFM.importURL(qurl, sampleRate);
     } catch (AudioFileManager::BadAudioPathException e) {
         CurrentProgressDialog::freeze();
+        if (progressDlg) progressDlg->close(); 
         QString errorString = tr("Can't add dropped file. ") + strtoqstr(e.getMessage());
         QMessageBox::warning(this, tr("Rosegarden"), errorString);
-        progressDlg->close(); 
         return ;
     } catch (SoundFile::BadSoundFileException e) {
         CurrentProgressDialog::freeze();
+        if (progressDlg) progressDlg->close(); 
         QString errorString = tr("Can't add dropped file. ") + strtoqstr(e.getMessage());
         QMessageBox::warning(this, tr("Rosegarden"), errorString);
-        progressDlg->close(); 
         return;
     }
 
-    progressDlg->close(); 
+    if (progressDlg) progressDlg->close(); 
              
     progressDlg = new ProgressDialog(tr("Generating audio preview..."),
                                (QWidget*)this);
@@ -1830,15 +1842,17 @@ RosegardenMainViewWidget::slotDroppedNewAudio(QString audioDesc)
         aFM.generatePreview(audioFileId);
     } catch (Exception e) {
         CurrentProgressDialog::freeze();
+        if (progressDlg) progressDlg->close(); 
         QString message = strtoqstr(e.getMessage()) + "\n\n" +
                           tr("Try copying this file to a directory where you have write permission and re-add it");
         QMessageBox::information(this, tr("Rosegarden"), message);
-        progressDlg->close(); 
         return;
     }
 
-    disconnect(progressDlg, SIGNAL(canceled()),
-               &aFM, SLOT(slotStopPreview()));
+    if (progressDlg) {
+        disconnect(progressDlg, SIGNAL(canceled()),
+                   &aFM, SLOT(slotStopPreview()));
+    }
 
     // add the file at the sequencer
     emit addAudioFile(audioFileId);
@@ -1859,7 +1873,7 @@ RosegardenMainViewWidget::slotDroppedNewAudio(QString audioDesc)
         
     }
     
-    progressDlg->close();  // note: Qt::WA_DeleteOnClose set
+    if (progressDlg) progressDlg->close();  // note: Qt::WA_DeleteOnClose set
     CurrentProgressDialog::set(0);
 }
 
@@ -1907,10 +1921,10 @@ RosegardenMainViewWidget::slotSetRecord(InstrumentId id, bool value)
         //
         m_instrumentParameterBox->setRecord(value);
     */
+#ifdef NOT_DEFINED
     Composition &comp = getDocument()->getComposition();
     Composition::trackcontainer &tracks = comp.getTracks();
     Composition::trackiterator it;
-#ifdef NOT_DEFINED
 
     for (it = tracks.begin(); it != tracks.end(); ++it) {
         if (comp.getSelectedTrack() == (*it).second->getId()) {
@@ -1921,8 +1935,8 @@ RosegardenMainViewWidget::slotSetRecord(InstrumentId id, bool value)
         }
     }
 #endif
-    Studio &studio = getDocument()->getStudio();
-    Instrument *instr = studio.getInstrumentById(id);
+    // Studio &studio = getDocument()->getStudio();
+    // Instrument *instr = studio.getInstrumentById(id);
 }
 
 void
@@ -2110,14 +2124,17 @@ RosegardenMainViewWidget::slotControllerDeviceEventReceived(MappedEvent *e, cons
         return ;
     }
 
-    unsigned int channel = e->getRecordedChannel();
+    // unsigned int channel = e->getRecordedChannel();
     MidiByte controller = e->getData1();
     MidiByte value = e->getData2();
 
-    if (controller == 82) { //!!! magic select-track controller
+    if (controller == 82) { // !!! magic select-track controller
         int tracks = comp.getNbTracks();
-        Track *track = comp.getTrackByPosition(value * tracks / 127);
+        Track *track = comp.getTrackByPosition(value * tracks / 128);
         if (track) {
+            comp.setSelectedTrack(track->getId());
+            comp.notifyTrackSelectionChanged(track->getId());
+
             slotSelectTrackSegments(track->getId());
         }
         return ;
