@@ -15,8 +15,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _RG_ROSEGARDENGUIAPP_H_
-#define _RG_ROSEGARDENGUIAPP_H_
+#ifndef RG_ROSEGARDENMAINWINDOW_H
+#define RG_ROSEGARDENMAINWINDOW_H
 
 #include "base/MidiProgram.h"
 #include "gui/dialogs/TempoDialog.h"
@@ -1703,6 +1703,7 @@ private:
     TempoView             *m_tempoView;
     TriggerSegmentManager *m_triggerSegmentManager;
     std::set<ControlEditorDialog *> m_controlEditors;
+    /// List of plugin dialogs to make sure we don't launch more than one.
     std::map<int, AudioPluginDialog*> m_pluginDialogs;
     AudioPluginOSCGUIManager *m_pluginGUIManager;
 
