@@ -585,6 +585,19 @@ NotationConfigurationPage::NotationConfigurationPage(QWidget *parent) :
     layout->addWidget(m_hideRedundantClefKey, row, 2);
     ++row;
 
+    layout->addWidget
+        (new QLabel
+         (tr("Distribute verses among repeated segments"), frame),
+         row, 0, 1, 2);
+    m_distributeVerses = new QCheckBox(frame);
+    connect(m_distributeVerses, SIGNAL(stateChanged(int)),
+            this, SLOT(slotModified()));
+    bool defaultDistributeVerses =
+        qStrToBool(settings.value("distributeverses", "true")) ;
+    m_distributeVerses->setChecked(defaultDistributeVerses);
+    layout->addWidget(m_distributeVerses, row, 2);
+    ++row;
+
 
     layout->setRowStretch(row, 10);
     frame->setLayout(layout);
@@ -753,6 +766,8 @@ NotationConfigurationPage::apply()
     settings.setValue("editrepeated", m_editRepeated->isChecked());
     settings.setValue("hideredundantclefkey",
                        m_hideRedundantClefKey->isChecked());
+    settings.setValue("distributeverses",
+                       m_distributeVerses->isChecked());
 
     settings.endGroup();
 }
