@@ -78,10 +78,14 @@ NotationHLayout::NotationHLayout(Composition *c, NotePixmapFactory *npf,
 
     QSettings settings;
     settings.beginGroup(NotationOptionsConfigGroup);
-
     m_keySigCancelMode = settings.value("keysigcancelmode", 1).toInt() ;
     m_hideRedundance = settings.value("hideredundantclefkey", "true").toBool();
     settings.endGroup();
+
+    settings.beginGroup(NotationViewConfigGroup);
+    m_showRepeated =  settings.value("showrepeated", true).toBool();
+    m_distributeVerses =  settings.value("distributeverses", true).toBool();
+    settings.endGroup();
 }
 
 NotationHLayout::~NotationHLayout()
@@ -92,7 +96,7 @@ NotationHLayout::~NotationHLayout()
 std::vector<int>
 NotationHLayout::getAvailableSpacings()
 {
-    if (m_availableSpacings.size() == 0) {
+    if (m_availableSpacings.empty()) {
         m_availableSpacings.push_back(30);
         m_availableSpacings.push_back(60);
         m_availableSpacings.push_back(85);
@@ -107,7 +111,7 @@ NotationHLayout::getAvailableSpacings()
 std::vector<int>
 NotationHLayout::getAvailableProportions()
 {
-    if (m_availableProportions.size() == 0) {
+    if (m_availableProportions.empty()) {
         m_availableProportions.push_back(0);
         m_availableProportions.push_back(20);
         m_availableProportions.push_back(40);
@@ -344,7 +348,7 @@ NotationHLayout::scanViewSegment(ViewSegment &staff, timeT startTime,
         chunks.clear();
 
         float lyricWidth = 0;
-        int graceCount = 0;
+        // int graceCount = 0;
 
         typedef std::set
             <long> GroupIdSet;
@@ -420,17 +424,23 @@ NotationHLayout::scanViewSegment(ViewSegment &staff, timeT startTime,
 
             } else if (el->event()->isa(Text::EventType)) {
 
+                bool isLyric = el->event()->has(Text::TextTypePropertyName) &&
+                    el->event()->get<String>(Text::TextTypePropertyName) ==
+                    Text::Lyric;
+                bool verseOk = el->event()->has(Text::LyricVersePropertyName) &&
+                    el->event()->get<Int>(Text::LyricVersePropertyName) ==
+                    segment.getVerseWrapped();
+
                 // the only text events of interest are lyrics, which
                 // contribute to a fixed area following the next chord
 
-                if (el->event()->has(Text::TextTypePropertyName) &&
-                    el->event()->get<String>(Text::TextTypePropertyName) ==
-                    Text::Lyric) {
+                if (isLyric && (!m_distributeVerses || (m_distributeVerses && verseOk))) {
                     lyricWidth = std::max
                         (lyricWidth, float(npf->getTextWidth(Text(*el->event()))));
                     NOTATION_DEBUG << "Setting lyric width to " << lyricWidth
                                    << " for text " << el->event()->get<String>(Text::TextPropertyName) << endl;
                 }
+
                 chunks.push_back(Chunk(el->event()->getSubOrdering(), 0));
 
             } else if (el->isNote()) {
@@ -841,7 +851,7 @@ NotationHLayout::preSquishBar(int barNo)
         timeT delay = std::numeric_limits<timeT>::max();
         BarData * dataPtr = 0;
         for (BarDataVector::iterator
-            j = i->second.begin(); j != i->second.end(); j++) {
+            j = i->second.begin(); j != i->second.end(); ++j) {
 
             // Hide all the time signatures
             (*j)->basicData.timeSignature.setHidden(true);  
@@ -1884,7 +1894,7 @@ NotationHLayout::positionChord(ViewSegment &staff,
 
 float
 NotationHLayout::getLayoutWidth(ViewElement &ve,
-                                NotePixmapFactory *npf,
+                                NotePixmapFactory */* npf */,
                                 const ::Rosegarden::Key &previousKey) const
 {
     NotationElement& e = static_cast<NotationElement&>(ve);
