@@ -374,6 +374,7 @@ NotationScene::createClonesFromRepeatedSegments()
             timeT repeatEnd = (*it)->getRepeatEndTime();
             timeT targetDuration = targetEnd - targetStart;
             TrackId track = (*it)->getTrack();
+            int verse = (*it)->getVerse();
 //             std::cerr << "Creating clones   track=" << track
 //                       << " targetStart=" << targetStart
 //                       << " targetEnd=" << targetEnd
@@ -388,6 +389,7 @@ NotationScene::createClonesFromRepeatedSegments()
 
                 s->setStartTime(ts);
                 s->setTrack(track);
+                s->setVerse(++verse);
                 s->setTmp();  // To avoid crash related to composition
                               // being undefined and to get notation
                               // with grey color
@@ -523,7 +525,7 @@ NotationScene::getNextStaffOnTrack()
 NotationStaff *
 NotationScene::getNextStaffVertically(int direction)
 {
-    if (m_staffs.size() < 2 || m_currentStaff >= m_staffs.size()) return 0;
+    if (m_staffs.size() < 2 || m_currentStaff >= (int)m_staffs.size()) return 0;
 
     NotationStaff *current = m_staffs[m_currentStaff];
     Composition *composition = &m_document->getComposition();
@@ -548,7 +550,7 @@ NotationScene::getNextStaffVertically(int direction)
 NotationStaff *
 NotationScene::getNextStaffHorizontally(int direction, bool cycle)
 {
-    if (m_staffs.size() < 2 || m_currentStaff >= m_staffs.size()) return 0;
+    if (m_staffs.size() < 2 || m_currentStaff >= (int)m_staffs.size()) return 0;
 
     NotationStaff *current = m_staffs[m_currentStaff];
     //Composition *composition = &m_document->getComposition();
@@ -1859,7 +1861,7 @@ NotationScene::constrainToSegmentArea(QPointF &scenePos)
 }
 
 bool
-NotationScene::isEventRedundant(Event *ev, Segment &seg)
+NotationScene::isEventRedundant(Event *ev, Segment &seg) const
 {
     if (ev->isa(Clef::EventType)) {
         Clef clef = Clef(*ev);
@@ -1888,7 +1890,7 @@ NotationScene::isEventRedundant(Event *ev, Segment &seg)
 }
 
 bool
-NotationScene::isEventRedundant(Clef &clef, timeT time, Segment &seg)
+NotationScene::isEventRedundant(Clef &clef, timeT time, Segment &seg) const
 {
     TrackId track = seg.getTrack();
     Clef previousClef = m_clefKeyContext->getClefFromContext(track, time);
@@ -1902,7 +1904,7 @@ NotationScene::isEventRedundant(Clef &clef, timeT time, Segment &seg)
 }
 
 bool
-NotationScene::isEventRedundant(Key &key, timeT time, Segment &seg)
+NotationScene::isEventRedundant(Key &key, timeT time, Segment &seg) const
 {
     TrackId track = seg.getTrack();
     Key previousKey = m_clefKeyContext->getKeyFromContext(track, time);
