@@ -106,6 +106,8 @@ NotationStaff::NotationStaff(NotationScene *scene, Segment *segment,
 
     m_hideRedundance = settings.value("hideredundantclefkey", "true").toBool();
 
+    m_distributeVerses =  settings.value("distributeverses", true).toBool();
+
     settings.endGroup();
 
     setLineThickness(m_notePixmapFactory->getStaffLineThickness());
@@ -1027,6 +1029,19 @@ NotationStaff::renderSingleElement(ViewElementList::iterator &vli,
 
         } else if (elt->event()->isa(Text::EventType)) {
 
+            // If event is a lyric and doesn't have the verse property, the
+            // document was probably created before the multiple verses feature
+            // was written. In such a case there should be only one verse and
+            // the property is added with its value set to 0 (ie. first verse).
+            //!!! This code should be moved to the place where the rg file is read
+            if (elt->event()->has(Text::TextTypePropertyName) &&
+                  elt->event()->get<String>(Text::TextTypePropertyName) ==
+                  Text::Lyric) {
+                if (!elt->event()->has(Text::LyricVersePropertyName)) {
+                    elt->event()->set<Int>(Text::LyricVersePropertyName, 0);
+                }
+            }
+
             policy = MoveBackToFit;
 
             if (elt->event()->has(Text::TextTypePropertyName) &&
@@ -1036,14 +1051,24 @@ NotationStaff::renderSingleElement(ViewElementList::iterator &vli,
 
                 // nothing I guess
 
-            }
-            else if (elt->event()->has(Text::TextTypePropertyName) &&
-                     elt->event()->get<String>(Text::TextTypePropertyName) ==
-                     Text::LilyPondDirective &&
-                     !m_notationScene->areLilyPondDirectivesVisible()) {
+            } else if (elt->event()->has(Text::TextTypePropertyName) &&
+                       elt->event()->get<String>(Text::TextTypePropertyName) ==
+                       Text::LilyPondDirective &&
+                       !m_notationScene->areLilyPondDirectivesVisible()) {
 
                 // nothing here either
 
+            } else if (m_distributeVerses && 
+                       elt->event()->has(Text::TextTypePropertyName) &&
+                       elt->event()->get<String>(Text::TextTypePropertyName) ==
+                       Text::Lyric &&
+                       elt->event()->get<Int>(Text::LyricVersePropertyName) !=
+                       getSegment().getVerseWrapped()) {
+
+                // nothing here either
+                // (this verse have to be displayed with another view of
+                //  the current segment)
+
             } else {
 
                 try {
@@ -1085,7 +1110,8 @@ NotationStaff::renderSingleElement(ViewElementList::iterator &vli,
 
                 std::string indicationType = indication.getIndicationType();
 
-                int length, y1;
+                int length;
+                // int y1;
 
                 if ((indicationType == Indication::Slur ||
                         indicationType == Indication::PhrasingSlur) &&
@@ -1120,7 +1146,7 @@ NotationStaff::renderSingleElement(ViewElementList::iterator &vli,
                     }
                 }
 
-                y1 = (int)(*indicationEnd)->getLayoutY();
+                // y1 = (int)(*indicationEnd)->getLayoutY();
 
                 if (length < m_notePixmapFactory->getNoteBodyWidth()) {
                     length = m_notePixmapFactory->getNoteBodyWidth();
@@ -2110,7 +2136,14 @@ NotationStaff::getBarInset(int barNo, bool isFirstBarInRow) const
                     }
                 }
 
-                haveKey = true;
+                // Is the key hide because redundant ?
+                if (m_hideRedundance &&
+                    m_notationScene->isEventRedundant(const_cast<Event *>(*i),
+                                                      const_cast<Segment &>(getSegment()))) {
+                    haveKey = false;
+                } else {
+                    haveKey = true;
+                }
 
             } catch (...) {
                 NOTATION_DEBUG << "getBarInset: Bad key in event" << endl;
@@ -2120,7 +2153,15 @@ NotationStaff::getBarInset(int barNo, bool isFirstBarInRow) const
 
             try {
                 clef = Clef(**i);
-                haveClef = true;
+ 
+                // Is the clef hide because redundant ?
+                if (m_hideRedundance &&
+                    m_notationScene->isEventRedundant(const_cast<Event *>(*i),
+                                                      const_cast<Segment &>(getSegment()))) {
+                    haveClef = false;
+                } else {
+                    haveClef = true;
+                }
             } catch (...) {
                 NOTATION_DEBUG << "getBarInset: Bad clef in event" << endl;
             }
