@@ -76,11 +76,11 @@ public:
         m_barNumbersEvery = barNumbersEvery;
     }
 
-    StaffLayout::setPageMode;
-    StaffLayout::setPageWidth;
-    StaffLayout::setRowsPerPage;
-    StaffLayout::setRowSpacing;
-    StaffLayout::setConnectingLineLength;
+    using StaffLayout::setPageMode;
+    using StaffLayout::setPageWidth;
+    using StaffLayout::setRowsPerPage;
+    using StaffLayout::setRowSpacing;
+    using StaffLayout::setConnectingLineLength;
 
     SegmentRefreshStatus &getRefreshStatus() const;
     void resetRefreshStatus();
@@ -399,6 +399,7 @@ protected:
     bool m_showRanges;
     bool m_showCollisions;
     bool m_hideRedundance;
+    bool m_distributeVerses;
     int m_keySigCancelMode;
 
     QPainter *m_printPainter;
