@@ -33,6 +33,7 @@
 #include <vector>
 
 class QWidget;
+class Event;
 
 namespace Rosegarden
 {
@@ -43,7 +44,9 @@ class NotationElement;
 class NotationStaff;
 class Segment;
 class CommandRegistry;
-	
+class ControlRulerWidget;
+class ControlParameter;
+ 
 class NotationView : public EditViewBase,
                         public SelectionManager
 {
@@ -64,6 +67,8 @@ public:
     void initRulersToolbar();
     virtual void initStatusBar();
     virtual timeT getInsertionTime() const;
+    
+    bool hasSegment(Segment * seg) const;
 
     /** This turns out to be cruft that is rather annoying to eliminate.  We
      * don't use this for anything, and provide an empty implementation.
@@ -134,6 +139,10 @@ protected slots:
     void slotVelocityUp();
     void slotVelocityDown();
     void slotSetVelocities();
+    void slotEditCutControllers();
+    void slotEditCopyControllers();
+    void slotSetControllers();
+    void slotPlaceControllers();
 
     void slotSetSelectTool();
     void slotSetEraseTool();
@@ -348,6 +357,7 @@ protected slots:
 
     // Open insert pitch bends sequence dialog
     void slotPitchBendSequence();
+    void slotControllerSequence();
 
     // Update the "Show staff headers" check box in the menu
     void slotCheckShowHeadersMenu(bool checked);
@@ -431,6 +441,10 @@ private:
     void setCurrentNotePixmap(QPixmap);
     void setCurrentNotePixmapFrom(QAction *);
 
+    bool isShowable(Event *e);
+    void conformRulerSelectionState(void);
+    void insertControllerSequence(const ControlParameter &cp);
+
 // FIXME: likely to be debated. --gp     Used for subclassing in pitchtracker
 protected:
     RosegardenDocument *m_document;
