@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2011 the Rosegarden development team.
+    Copyright 2000-2012 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -55,8 +55,15 @@ public:
 
     void showAdditionalControls(bool showThem);
 
+ protected:
+    void setSelectedInstrument(Instrument *instrument, QString label);
+ public:
 signals:
     void updateAllBoxes();
+
+private slots:
+    /// Instrument is being destroyed
+    void slotInstrumentGone(void);
         
 protected:
     //--------------- Data members ---------------------------------
