@@ -539,7 +539,7 @@ SegmentParameterBox::populateBoxFromSegments()
     m_repeatValue->setEnabled(false);
 
 
-    for (it = m_segments.begin(); it != m_segments.end(); it++) {
+    for (it = m_segments.begin(); it != m_segments.end(); ++it) {
         // ok, first thing is we know we have at least one segment
         //
         // and since there is at least one segment, we can re-enable the edit button
@@ -701,6 +701,7 @@ SegmentParameterBox::populateBoxFromSegments()
 
         // Assuming "Off" is always the last field
     case None:
+    case NotApplicable:
     default:
         m_quantizeValue->setCurrentIndex(m_quantizeValue->count() - 1);
         break;
@@ -709,23 +710,18 @@ SegmentParameterBox::populateBoxFromSegments()
     m_quantizeValue->setEnabled(quantized != NotApplicable);
 
     switch (transposed) {
-        // setCurrentIndex works with QStrings
-        // 2nd arg of "true" means "add if necessary"
     case All:
-        m_transposeValue->
-//           setCurrentIndex(QString("%1").arg(transposeLevel), true);
-          setItemText(m_transposeValue->currentIndex(), QString("%1").arg(transposeLevel) );
+          m_transposeValue->setCurrentIndex(m_transposeValue->findText(QString("%1").arg(transposeLevel)));
           break;
 
     case Some:
-//           m_transposeValue->setCurrentIndex(QString(""), true);
-          m_transposeValue->setItemText(m_transposeValue->currentIndex(), QString(""));
+          m_transposeValue->setCurrentIndex(m_transposeValue->findText(QString("")));
           break;
 
     case None:
+    case NotApplicable:
     default:
-//           m_transposeValue->setCurrentIndex("0");
-          m_transposeValue->setItemText(m_delayValue->currentIndex(), "0");
+          m_transposeValue->setCurrentIndex(m_transposeValue->findText(QString("0")));
           break;
     }
 
@@ -740,25 +736,23 @@ SegmentParameterBox::populateBoxFromSegments()
             QString label = NotationStrings::makeNoteMenuLabel(delayLevel,
                             true,
                             error);
-//                m_delayValue->setCurrentIndex(label, true);
-               m_delayValue->setItemText(m_delayValue->currentIndex(), label);
+               m_delayValue->setCurrentIndex(m_delayValue->findText(label));
 
         } else if (delayLevel < 0) {
 
-//                m_delayValue->setCurrentIndex(tr("%1 ms").arg(-delayLevel),true);
-               m_delayValue->setItemText(m_delayValue->currentIndex(), tr("%1 ms").arg(-delayLevel) );
+               m_delayValue->setCurrentIndex(m_delayValue->findText( tr("%1 ms").arg(-delayLevel) ));
           }
 
         break;
 
     case Some:
-//           m_delayValue->setCurrentIndex("", true);
-          m_delayValue->setItemText(m_delayValue->currentIndex(), "");
+          m_delayValue->setCurrentIndex(m_delayValue->findText(QString("")));
           break;
 
     case None:
+    case NotApplicable:
     default:
-        m_delayValue->setCurrentIndex(0);
+        m_delayValue->setCurrentIndex(m_delayValue->findText(QString("0")));
         break;
     }
 
@@ -777,6 +771,7 @@ SegmentParameterBox::populateBoxFromSegments()
 
     case All:
     case NotApplicable:
+    case Some:
     default:
         m_colourValue->setCurrentIndex(0);
         break;
@@ -828,7 +823,7 @@ SegmentParameterBox::slotQuantizeSelected(int qLevel)
         (off ? 0 : m_standardQuantizations[qLevel]);
 
     std::vector<Segment*>::iterator it;
-    for (it = m_segments.begin(); it != m_segments.end(); it++) {
+    for (it = m_segments.begin(); it != m_segments.end(); ++it) {
         command->addSegment(*it);
     }
 
@@ -847,7 +842,7 @@ SegmentParameterBox::slotTransposeTextChanged(const QString &text)
     //                                                                transposeValue));
 
     std::vector<Segment*>::iterator it;
-    for (it = m_segments.begin(); it != m_segments.end(); it++) {
+    for (it = m_segments.begin(); it != m_segments.end(); ++it) {
         (*it)->setTranspose(transposeValue);
     }
 
@@ -869,7 +864,7 @@ SegmentParameterBox::slotChangeLinkTranspose()
     bool foundTransposedLinks = false;
     std::vector<Segment *> linkedSegs;
     std::vector<Segment *>::iterator it;
-    for (it = m_segments.begin(); it != m_segments.end(); it++) {
+    for (it = m_segments.begin(); it != m_segments.end(); ++it) {
         Segment *linkedSeg = *it;
         if (linkedSeg->isLinked()) {
             if (linkedSeg->getLinkTransposeParams().m_semitones==0) {
@@ -917,7 +912,7 @@ SegmentParameterBox::slotResetLinkTranspose()
 
     std::vector<Segment *> linkedSegs;
     std::vector<Segment *>::iterator it;
-    for (it = m_segments.begin(); it != m_segments.end(); it++) {
+    for (it = m_segments.begin(); it != m_segments.end(); ++it) {
         Segment *linkedSeg = *it;
         if (linkedSeg->isLinked()) {
             linkedSegs.push_back(linkedSeg);
@@ -948,7 +943,7 @@ SegmentParameterBox::slotDelayTimeChanged(timeT delayValue)
     if (delayValue > 0) {
 
         std::vector<Segment*>::iterator it;
-        for (it = m_segments.begin(); it != m_segments.end(); it++) {
+        for (it = m_segments.begin(); it != m_segments.end(); ++it) {
             (*it)->setDelay(delayValue);
             (*it)->setRealTimeDelay(RealTime::zeroTime);
         }
@@ -956,7 +951,7 @@ SegmentParameterBox::slotDelayTimeChanged(timeT delayValue)
     } else if (delayValue < 0) {
 
         std::vector<Segment*>::iterator it;
-        for (it = m_segments.begin(); it != m_segments.end(); it++) {
+        for (it = m_segments.begin(); it != m_segments.end(); ++it) {
             (*it)->setDelay(0);
             int sec = ( -delayValue) / 1000;
             int nsec = (( -delayValue) - 1000 * sec) * 1000000;
@@ -965,7 +960,7 @@ SegmentParameterBox::slotDelayTimeChanged(timeT delayValue)
     } else {
 
         std::vector<Segment*>::iterator it;
-        for (it = m_segments.begin(); it != m_segments.end(); it++) {
+        for (it = m_segments.begin(); it != m_segments.end(); ++it) {
             (*it)->setDelay(0);
             (*it)->setRealTimeDelay(RealTime::zeroTime);
         }
@@ -1069,7 +1064,7 @@ SegmentParameterBox::slotHighestPressed()
         m_highestPlayable = dialog.getPitch();
         updateHighLow();
 
-        for (it = m_segments.begin(); it != m_segments.end(); it++) {
+        for (it = m_segments.begin(); it != m_segments.end(); ++it) {
             (*it)->setHighestPlayable(m_highestPlayable);
         }
 
@@ -1089,7 +1084,7 @@ SegmentParameterBox::slotLowestPressed()
         m_lowestPlayable = dialog.getPitch();
         updateHighLow();
 
-        for (it = m_segments.begin(); it != m_segments.end(); it++) {
+        for (it = m_segments.begin(); it != m_segments.end(); ++it) {
             (*it)->setLowestPlayable(m_lowestPlayable);
         }
 
@@ -1182,7 +1177,7 @@ SegmentParameterBox::slotFadeOutChanged(int value)
 }
 
 void
-SegmentParameterBox::showAdditionalControls(bool showThem)
+SegmentParameterBox::showAdditionalControls(bool /* showThem */)
 {
 }
 
