@@ -511,7 +511,7 @@ TrackParameterBox::populatePlaybackDeviceList()
     InstrumentList::iterator it;
     int currentDevId = -1;
 
-    for (it = list.begin(); it != list.end(); it++) {
+    for (it = list.begin(); it != list.end(); ++it) {
 
         if (! (*it))
             continue; // sanity check
@@ -709,7 +709,7 @@ TrackParameterBox::slotUpdateControls(int /*dummy*/)
     Track *trk = comp.getTrackById(m_selectedTrackId);
 
     m_defClef->setCurrentIndex(trk->getClef());
-    m_defTranspose->setItemText(m_defTranspose->currentIndex(), QString("%1").arg(trk->getTranspose()));
+    m_defTranspose->setCurrentIndex(m_defTranspose->findText(QString("%1").arg(trk->getTranspose())));
     m_defColor->setCurrentIndex(trk->getColor());
     m_highestPlayable = trk->getHighestPlayable();
     m_lowestPlayable = trk->getLowestPlayable();
@@ -750,10 +750,17 @@ TrackParameterBox::tracksDeleted(const Composition *, std::vector<TrackId> &trac
     }
 }
 
+void
+TrackParameterBox::trackSelectionChanged(const Composition *, TrackId)
+{
+    slotSelectedTrackChanged();
+}
+
 void
 TrackParameterBox::slotSelectedTrackChanged()
 {
-    RG_DEBUG << "TrackParameterBox::slotSelectedTrackChanged()\n";
+    RG_DEBUG << "TrackParameterBox::slotSelectedTrackChanged()";
+
     Composition &comp = m_doc->getComposition();
     TrackId newTrack = comp.getSelectedTrack();
     if ((int)newTrack != m_selectedTrackId) {
@@ -892,7 +899,7 @@ TrackParameterBox::slotInstrumentChanged(int index)
         // swallowing two entire days of my life to put back with the following
         // magic lines of code:
         int prepend = 0;
-        for (unsigned int n = 0; n < m_playDevice->currentIndex(); n++) {
+        for (int n = 0; n < m_playDevice->currentIndex(); n++) {
             DeviceId id = m_playDeviceIds[n];
             Device *dev = m_doc->getStudio().getDevice(id);
 
@@ -1176,12 +1183,8 @@ TrackParameterBox::slotPresetPressed()
                 CommandHistory::getInstance()->addCommand(command);
             }
             m_defClef->setCurrentIndex(dialog.getClef());
-//             m_defTranspose->setCurrentIndex(QString("%1").arg
-//                     (dialog.getTranspose()), true);
-
                      
-            m_defTranspose->setItemText(m_defTranspose->currentIndex(), QString("%1").arg
-                    (dialog.getTranspose()));
+            m_defTranspose->setCurrentIndex(m_defTranspose->findText(QString("%1").arg(dialog.getTranspose())));
 
             m_highestPlayable = dialog.getHighRange();
             m_lowestPlayable = dialog.getLowRange();
