@@ -37,8 +37,10 @@
 #include "gui/application/RosegardenMainWindow.h"
 #include "gui/general/GUIPalette.h"
 #include "gui/general/IconLoader.h"
+#include "gui/seqmanager/SequenceManager.h"
 #include "gui/widgets/LedButton.h"
 #include "sound/AudioFileManager.h"
+#include "sound/ControlBlock.h"
 #include "sound/PluginIdentifier.h"
 #include "sequencer/RosegardenSequencer.h"
 
@@ -121,7 +123,7 @@ TrackButtons::TrackButtons(RosegardenDocument* doc,
             this, SLOT(slotInstrumentMenu(int)));
 
     connect(m_clickedSigMapper, SIGNAL(mapped(int)),
-            this, SIGNAL(trackSelected(int)));
+            this, SLOT(slotTrackSelected(int)));
 
     // We have to force the height for the moment
     //
@@ -618,7 +620,7 @@ TrackButtons::populateInstrumentPopup(Instrument *thisTrackInstr, QMenu* instrum
     InstrumentList list = studio.getPresentationInstruments();
 
     // For each instrument
-    for (InstrumentList::iterator it = list.begin(); it != list.end(); it++) {
+    for (InstrumentList::iterator it = list.begin(); it != list.end(); ++it) {
 
         if (!(*it)) continue; // sanity check
 
@@ -820,13 +822,20 @@ TrackButtons::slotInstrumentSelected(int instrumentIndex)
     //RG_DEBUG << "TrackButtons::slotInstrumentSelected: instrument " << inst;
 
     if (inst != 0) {
+        Composition &comp = m_doc->getComposition();
         Track *track =
-                m_doc->getComposition().getTrackByPosition(m_popupTrackPos);
+                comp.getTrackByPosition(m_popupTrackPos);
 
         if (track != 0) {
-            // Select the new instrument for the track
+            // Select the new instrument for the track.  Seems like we
+            // need to do all 3 ways:
+            // For Track.cpp
             track->setInstrument(inst->getId());
+            // For TrackParameterBox
             emit instrumentSelected((int)inst->getId());
+            // For ControlBlock's representation of track.
+            ControlBlock::getInstance()->
+                setInstrumentForTrack(m_popupTrackPos, inst->getId());
 
             // Update the instrument names
             initInstrumentNames(inst, m_trackLabels[m_popupTrackPos]);
@@ -835,6 +844,20 @@ TrackButtons::slotInstrumentSelected(int instrumentIndex)
             // Udpate the LED color
             m_recordLeds[m_popupTrackPos]->setColor(getRecordLedColour(inst));
 
+            SequenceManager *sM =
+                m_doc->getSequenceManager();
+
+            // Segments on this track are now playing on a new
+            // instrument, so they're no longer ready (making them
+            // ready is done just-in-time elsewhere), nor is thru
+            // channel ready.
+            for (Composition::iterator i =
+                     comp.begin();
+                 i != comp.end(); ++i) {
+                if (((int)(*i)->getTrack()) == m_popupTrackPos) {
+                    sM->segmentInstrumentChanged(*i);
+                }
+            }    
         } else {
             RG_DEBUG << "slotInstrumentSelected() - can't find track!\n";
         }
@@ -1102,5 +1125,29 @@ TrackButtons::tracksDeleted(const Composition *, std::vector<TrackId> &/*trackId
     slotUpdateTracks();
 }
 
+void
+TrackButtons::trackSelectionChanged(const Composition *, TrackId trackId)
+{
+    //RG_DEBUG << "TrackButtons::trackSelectionChanged()" << trackId;
+    Track *track = m_doc->getComposition().getTrackById(trackId);
+    selectTrack(track->getPosition());
+}
+
+void
+TrackButtons::slotTrackSelected(int trackId)
+{
+    // Select the track.
+    m_doc->getComposition().setSelectedTrack(trackId);
+
+    // New notification mechanism
+    // ??? Wouldn't a track pointer be more convenient for all involved?
+    m_doc->getComposition().notifyTrackSelectionChanged(trackId);
+
+    // Old mechanism.  Keeping this until we can completely replace it
+    // with the new mechanism above.
+    emit trackSelected(trackId);
+}
+
+
 }
 #include "TrackButtons.moc"
