@@ -101,9 +101,6 @@ public:
     /// Handles a change to the Program in the Instrument Parameters box.
     void changeInstrumentName(InstrumentId id, QString programChangeName);
 
-    /// Select the given track.  This displays it with a highlight.
-    void selectTrack(int position);
-
     /// Fill the instrument popup menu with the available instruments.
     /**
      * @see RosegardenMainWindow::slotPopulateTrackInstrumentPopup()
@@ -113,7 +110,7 @@ public:
 signals:
     /// Emitted when a track button has been clicked.
     /**
-     * Emitted by m_clickedSigMapper.
+     * Emitted by slotTrackSelected().
      * Handled by RosegardenMainViewWidget::slotSelectTrackSegments().
      *
      * @see slotLabelSelected()
@@ -288,6 +285,7 @@ protected:
     virtual void tracksAdded(const Composition *, std::vector<TrackId> &trackIds);
     virtual void trackChanged(const Composition *, Track*);
     virtual void tracksDeleted(const Composition *, std::vector<TrackId> &trackIds);
+    virtual void trackSelectionChanged(const Composition *, TrackId trackId);
 
     int labelWidth();
     int trackHeight(TrackId trackId);
@@ -350,10 +348,17 @@ protected:
     static const int m_vuWidth;
     static const int m_vuSpacing;
 
+private slots:
+    /// Handles clicks from m_clickedSigMapper.
+    void slotTrackSelected(int trackId);
+
 private:
     // Hide copy ctor and op=
     TrackButtons(const TrackButtons &);
     TrackButtons &operator=(const TrackButtons &);
+
+    /// Select the given track.  This displays it with a highlight.
+    void selectTrack(int position);
 };
 
 
