@@ -256,8 +256,9 @@ TrackEditor::init(QWidget* rosegardenguiview)
     connect(this, SIGNAL(stateChange(QString, bool)),
             rosegardenguiview, SIGNAL(stateChange(QString, bool)));
 
-    connect(m_trackButtons, SIGNAL(modified()),
-            m_doc, SLOT(slotDocumentModified()));
+    // No such signal.  Was there ever?
+//    connect(m_trackButtons, SIGNAL(modified()),
+//            m_doc, SLOT(slotDocumentModified()));
 
     // connect loop rulers' follow-scroll signals
     connect(m_topStandardRuler->getLoopRuler(), SIGNAL(startMouseMove(int)),
@@ -698,7 +699,7 @@ TrackEditor::slotDeleteSelectedSegments()
 
     // Create the compound command
     //
-    for (it = segments.begin(); it != segments.end(); it++) {
+    for (it = segments.begin(); it != segments.end(); ++it) {
         macro->addCommand(new SegmentEraseCommand(*it,
                           &m_doc->getAudioFileManager()));
     }
@@ -723,7 +724,7 @@ TrackEditor::slotTurnRepeatingSegmentToRealCopies()
     MacroCommand *macro = new MacroCommand(text);
 
     SegmentSelection::iterator it = segments.begin();
-    for (; it != segments.end(); it++) {
+    for (; it != segments.end(); ++it) {
         if ((*it)->isRepeating()) {
             macro->addCommand(new SegmentRepeatToCopyCommand(*it));
         }
@@ -748,7 +749,7 @@ TrackEditor::slotTurnLinkedSegmentsToRealCopies()
     MacroCommand *macro = new MacroCommand(text);
 
     SegmentSelection::iterator it = segments.begin();
-    for (; it != segments.end(); it++) {
+    for (; it != segments.end(); ++it) {
         if ((*it)->isLinked()) {
             macro->addCommand(new SegmentLinkToCopyCommand(*it));
         }
