@@ -186,7 +186,7 @@ EditViewBase::slotOpenInPitchTracker()
     emit slotOpenInPitchTracker(m_segments);
 }
 
-void EditViewBase::closeEvent(QCloseEvent* e)
+void EditViewBase::closeEvent(QCloseEvent* /* e */)
 {
     RG_DEBUG << "EditViewBase::closeEvent()\n";
 /*!!!
@@ -266,14 +266,18 @@ EditViewBase::slotToggleSolo()
 
     bool newSoloState = toggleSoloAction->isChecked();
 
-    RG_DEBUG << "EditViewBase::slotToggleSolo() : solo action is "
-             << (toggleSoloAction->isCheckable() ? "" : "NOT")
-             << " checkable." << endl;
+    //RG_DEBUG << "EditViewBase::slotToggleSolo() : solo action is " << (toggleSoloAction->isCheckable() ? "" : "NOT") << " checkable.";
+    //RG_DEBUG << "EditViewBase::slotToggleSolo() : solo  = " << newSoloState;
 
-    RG_DEBUG << "EditViewBase::slotToggleSolo() : solo  = " << newSoloState << endl;
     emit toggleSolo(newSoloState);
 
     if (newSoloState) {
+        getDocument()->getComposition().setSelectedTrack(
+                getCurrentSegment()->getTrack());
+        getDocument()->getComposition().notifyTrackSelectionChanged(
+                getCurrentSegment()->getTrack());
+
+        // Old notification mechanism.
         emit selectTrack(getCurrentSegment()->getTrack());
     }
 }
@@ -348,7 +352,7 @@ EditViewBase::slotCompositionStateUpdate()
 }
 
 void
-EditViewBase::windowActivationChange(bool oldState)
+EditViewBase::windowActivationChange(bool /* oldState */)
 {
     if (isActiveWindow()) {
         emit windowActivated();
@@ -356,7 +360,7 @@ EditViewBase::windowActivationChange(bool oldState)
 }
 
 void
-EditViewBase::handleEventRemoved(Event *event)
+EditViewBase::handleEventRemoved(Event */* event */)
 {
 }
 
