@@ -158,7 +158,8 @@ ChordNameRuler::setStudio(Studio *studio)
 void
 ChordNameRuler::slotScrollHoriz(int x)
 {
-    int w = width(), h = height();
+    int w = width();
+    // int h = height();
     int dx = x - ( -m_currentXOffset);
     m_currentXOffset = -x;
 
