@@ -64,7 +64,7 @@ const int ControlRuler::MinItemHeight = 5;
 const int ControlRuler::MaxItemHeight = 64 + 5;
 const int ControlRuler::ItemHeightRange = 64;
 
-ControlRuler::ControlRuler(ViewSegment *viewsegment,
+    ControlRuler::ControlRuler(ViewSegment */*viewsegment*/,
                            RulerScale* rulerScale,
                            QWidget* parent
 						  ) :
@@ -75,6 +75,9 @@ ControlRuler::ControlRuler(ViewSegment *viewsegment,
         m_notationStaff(0),
         m_segment(0),
 //        m_assignedEventSelection(0),
+        m_firstVisibleItem(m_controlItemMap.end()),
+        m_lastVisibleItem(m_controlItemMap.end()),
+        m_nextItemLeft(m_controlItemMap.end()),
         m_currentIndex(0),
         m_currentTool(0),
         m_xScale(0),
@@ -87,10 +90,7 @@ ControlRuler::ControlRuler(ViewSegment *viewsegment,
         m_itemMoved(false),
         m_selecting(false),
         m_selectionRect(0),
-        m_menu(0),
-        m_firstVisibleItem(m_controlItemMap.end()),
-        m_lastVisibleItem(m_controlItemMap.end()),
-        m_nextItemLeft(m_controlItemMap.end())
+        m_menu(0)
 {
 //    setViewSegment(viewsegment);
 
@@ -144,14 +144,14 @@ ControlItemMap::iterator ControlRuler::findControlItem(float x)
 
 ControlItemMap::iterator ControlRuler::findControlItem(const Event *event)
 {
-    double xstart = getRulerScale()->getXForTime(event->getAbsoluteTime());
+    // double xstart = getRulerScale()->getXForTime(event->getAbsoluteTime());
 
     ControlItemMap::iterator it;
     std::pair <ControlItemMap::iterator,ControlItemMap::iterator> ret;
 
 //    ret = m_controlItemMap.equal_range(xstart);
 //    for (it = ret.first; it != ret.second; it++) {
-    for (it = m_controlItemMap.begin(); it != m_controlItemMap.end(); it++) {
+    for (it = m_controlItemMap.begin(); it != m_controlItemMap.end(); ++it) {
         if (it->second->getEvent() == event) break;
     }
 
@@ -167,7 +167,7 @@ ControlItemMap::iterator ControlRuler::findControlItem(const ControlItem* item)
 {
     // Basic loop through until I get the equal_range thing working properly
     ControlItemMap::iterator it;
-    for (it = m_controlItemMap.begin(); it != m_controlItemMap.end(); it++) {
+    for (it = m_controlItemMap.begin(); it != m_controlItemMap.end(); ++it) {
         if (it->second == item) break;
     }
     return it;
@@ -269,7 +269,7 @@ void ControlRuler::removeCheckVisibleLimits(const ControlItemMap::iterator &it)
     // If this was the first visible item
     if (it == m_firstVisibleItem) {
         // Check the next item to the right
-        m_firstVisibleItem++;
+        ++m_firstVisibleItem;
         // If the next item to the right is invisible, there are no visible items
         // Note we have to check .end() before we dereference ->second
         if (m_firstVisibleItem != m_controlItemMap.end() &&
@@ -282,7 +282,7 @@ void ControlRuler::removeCheckVisibleLimits(const ControlItemMap::iterator &it)
         // and not the first in the list
         if (it != m_controlItemMap.begin()) {
             // check the next item to the left
-            m_lastVisibleItem--;
+            --m_lastVisibleItem;
             // If this is invisible, there are no visible items
             if (visiblePosition(m_lastVisibleItem->second)!=0) m_lastVisibleItem = m_controlItemMap.end();
         }
@@ -295,7 +295,7 @@ void ControlRuler::removeCheckVisibleLimits(const ControlItemMap::iterator &it)
         // and not the first in the list
         if (it != m_controlItemMap.begin()) {
             // use the next to the left (we know it is invisible)
-            m_nextItemLeft--;
+            --m_nextItemLeft;
         }
         // if it's first in the list then there are no invisible items to the left
         else m_nextItemLeft = m_controlItemMap.end();
@@ -365,7 +365,7 @@ void ControlRuler::updateSegment()
     // Either run through the ruler's EventSelection, updating from each item
     //  or, if there isn't one, go through m_selectedItems
     timeT start,end;
-    bool segmentModified = false;
+    // bool segmentModified = false;
 
     QString commandLabel = "Adjust control/property";
 
@@ -377,7 +377,7 @@ void ControlRuler::updateSegment()
     // EventSelection::addEvent adds timeT(1) to its extentt for zero duration events so need to mimic this here
     timeT durationAdd = 0;
 
-    for (ControlItemList::iterator it = m_selectedItems.begin(); it != m_selectedItems.end(); it++) {
+    for (ControlItemList::iterator it = m_selectedItems.begin(); it != m_selectedItems.end(); ++it) {
         if ((*it)->xStart() < xmin) xmin = (*it)->xStart();
         if ((*it)->xEnd() > xmax) {
             xmax = (*it)->xEnd();
@@ -402,7 +402,7 @@ void ControlRuler::updateSegment()
         commandLabel = "Add control";
         macro->setName(commandLabel);
 
-        segmentModified = true;
+        // segmentModified = true;
     } else {
         // Check for movement in time here and delete events if necessary
         if (start != m_eventSelection->getStartTime() || end != m_eventSelection->getEndTime()) {
@@ -413,7 +413,7 @@ void ControlRuler::updateSegment()
             start = std::min(start,m_eventSelection->getStartTime());
             end = std::max(end,m_eventSelection->getEndTime());
 
-            segmentModified = true;
+            // segmentModified = true;
         }
     }
 
@@ -437,7 +437,7 @@ void ControlRuler::slotUpdate()
 ///TODO Set some update flag?
 }
 
-void ControlRuler::notationLayoutUpdated(timeT startTime, timeT endTime)
+void ControlRuler::notationLayoutUpdated(timeT startTime, timeT /*endTime*/)
 {
     // notationLayoutUpdated should be called after notation has adjusted the layout
     // Clearly, for property control rulers, notes may have been moved so their position needs updating
@@ -471,7 +471,7 @@ void ControlRuler::notationLayoutUpdated(timeT startTime, timeT endTime)
     update();
 }
 
-void ControlRuler::paintEvent(QPaintEvent *event)
+void ControlRuler::paintEvent(QPaintEvent */*event*/)
 {
     RG_DEBUG << "ControlRuler::paintEvent: width()=" << width() << " height()=" << height();
     QPainter painter(this);
@@ -506,7 +506,7 @@ void ControlRuler::paintEvent(QPaintEvent *event)
     painter.drawLine(xstart, mapYToWidget(0.75f), xend, mapYToWidget(0.75f));
 }
 
-void ControlRuler::slotScrollHorizSmallSteps(int step)
+void ControlRuler::slotScrollHorizSmallSteps(int /*step*/)
 {
 }
 
@@ -537,7 +537,7 @@ QPolygon ControlRuler::mapItemToWidget(QPolygonF *poly)
 
     QPolygon newpoly;
     QPoint newpoint;
-    for (QPolygonF::iterator it = poly->begin(); it != poly->end(); it++) {
+    for (QPolygonF::iterator it = poly->begin(); it != poly->end(); ++it) {
         newpoint.setX(mapXToWidget((*it).x()));
         newpoint.setY(mapYToWidget((*it).y()));
         newpoly.push_back(newpoint);
@@ -602,7 +602,7 @@ void ControlRuler::resizeEvent(QResizeEvent *)
     slotSetPannedRect(m_pannedRect);
 }
 
-void ControlRuler::slotSetTool(const QString &matrixtoolname)
+void ControlRuler::slotSetTool(const QString &/*matrixtoolname*/)
 {
 }
 
@@ -659,7 +659,7 @@ void ControlRuler::mouseMoveEvent(QMouseEvent* e)
 }
 
 void
-ControlRuler::wheelEvent(QWheelEvent *e)
+ControlRuler::wheelEvent(QWheelEvent */*e*/)
 {
     // not sure what to do yet
 
@@ -715,7 +715,7 @@ void ControlRuler::updateSelection()
     if (m_eventSelection) delete m_eventSelection;
     m_eventSelection = new EventSelection(*m_segment);
 
-    for (ControlItemList::iterator it = m_selectedItems.begin(); it != m_selectedItems.end(); it++) {
+    for (ControlItemList::iterator it = m_selectedItems.begin(); it != m_selectedItems.end(); ++it) {
         m_eventSelection->addEvent((*it)->getEvent());
     }
 
@@ -725,6 +725,12 @@ void ControlRuler::updateSelection()
 
 void ControlRuler::addToSelection(ControlItem *item)
 {
+    ControlItemList::iterator found = 
+        std::find (m_selectedItems.begin(),
+                   m_selectedItems.end(), item);
+    
+    // If we already have this item, do nothing.
+    if (found != m_selectedItems.end()) { return; }
     m_selectedItems.push_back(item);
     item->setSelected(true);
     m_eventSelection->addEvent(item->getEvent());
@@ -788,14 +794,14 @@ QColor ControlRuler::valueToColour(int max, int val)
 void ControlRuler::flipForwards()
 {
     ///CJ Expect to drop tghis with a better way of ordering bars
-    std::pair<int, int> minMax = getZMinMax();
+    // std::pair<int, int> minMax = getZMinMax();
 
 }
 
 void ControlRuler::flipBackwards()
 {
     ///CJ Expect to drop tghis with a better way of ordering bars
-    std::pair<int, int> minMax = getZMinMax();
+    // std::pair<int, int> minMax = getZMinMax();
 
 }
 
