@@ -26,14 +26,16 @@
 #include "gui/editors/matrix/MatrixScene.h"
 
 #include "document/RosegardenDocument.h"
-#include "base/Controllable.h"
+#include "base/BaseProperties.h"
 #include "base/ControlParameter.h"
+#include "base/Controllable.h"
+#include "base/Event.h"
 #include "base/MidiDevice.h"
 #include "base/PropertyName.h"
-#include "base/BaseProperties.h"
-#include "base/Event.h"
 #include "base/RulerScale.h"
 #include "base/Selection.h"
+#include "base/SoftSynthDevice.h"
+#include "base/parameterpattern/SelectionSituation.h"
 
 #include "misc/Debug.h"
 
@@ -100,11 +102,16 @@ ControlRulerWidget::setSegments(RosegardenDocument *document, std::vector<Segmen
         getInstrumentById(track->getInstrument());
 
     if (instr) {
+        Device *device = instr->getDevice();
 
-        MidiDevice *device = dynamic_cast <MidiDevice*> (instr->getDevice());
+        // Cast to a Controllable if possible, otherwise leave c NULL.
+        Controllable *c =
+            dynamic_cast<MidiDevice *>(device);
+        if (!c)
+            { c = dynamic_cast<SoftSynthDevice *>(device); }
 
-        if (device) {
-            m_controlList = &(device->getControlParameters());
+        if (c) {
+            m_controlList = &(c->getControlParameters());
         }
     }
 
@@ -195,7 +202,7 @@ ControlRulerWidget::slotTogglePropertyRuler(const PropertyName &propertyName)
 {
     PropertyControlRuler *propruler;
     std::list<ControlRuler*>::iterator it;
-    for (it = m_controlRulerList.begin(); it != m_controlRulerList.end(); it++) {
+    for (it = m_controlRulerList.begin(); it != m_controlRulerList.end(); ++it) {
         propruler = dynamic_cast <PropertyControlRuler*> (*it);
         if (propruler) {
             if (propruler->getPropertyName() == propertyName)
@@ -218,7 +225,7 @@ ControlRulerWidget::slotToggleControlRuler(std::string controlName)
     ControlList::const_iterator it;
     // Check that the device supports a control parameter of this name
     for (it = m_controlList->begin();
-        it != m_controlList->end(); it++) {
+        it != m_controlList->end(); ++it) {
         if ((*it).getName() == controlName) {
             break;
         }
@@ -229,7 +236,7 @@ ControlRulerWidget::slotToggleControlRuler(std::string controlName)
         // Check whether we already have a control ruler for a control parameter of this name
         ControllerEventsRuler *eventruler;
         std::list<ControlRuler*>::iterator jt;
-        for (jt = m_controlRulerList.begin(); jt != m_controlRulerList.end(); jt++) {
+        for (jt = m_controlRulerList.begin(); jt != m_controlRulerList.end(); ++jt) {
             eventruler = dynamic_cast <ControllerEventsRuler*> (*jt);
             if (eventruler) {
                 if (eventruler->getControlParameter()->getName() == controlName)
@@ -382,7 +389,7 @@ ControlRulerWidget::slotSelectionChanged(EventSelection *s)
 }
 
 void
-ControlRulerWidget::slotHoveredOverNoteChanged(int evPitch, bool haveEvent, timeT evTime)
+ControlRulerWidget::slotHoveredOverNoteChanged(int /* evPitch */, bool /* haveEvent */, timeT /* evTime */)
 {
     slotHoveredOverNoteChanged();
 }
@@ -441,6 +448,56 @@ ControlRulerWidget::isAnyRulerVisible()
     return m_controlRulerList.size();
 }
 
+ControllerEventsRuler *
+ControlRulerWidget::getActiveRuler(void)
+{
+    QWidget * widget = m_stackedWidget->currentWidget ();
+    if (!widget) { return 0; }
+    return dynamic_cast <ControllerEventsRuler *> (widget);
+}
+
+bool
+ControlRulerWidget::hasSelection(void)
+{
+    ControllerEventsRuler *ruler = getActiveRuler();
+    if (!ruler) { return false; }
+    return ruler->getEventSelection() ? true : false;
+}
+
+// Return the active ruler's event selection, or NULL if none.
+// @author Tom Breton (Tehom)
+EventSelection *
+ControlRulerWidget::getSelection(void)
+{
+    ControllerEventsRuler *ruler = getActiveRuler();
+    if (!ruler) { return 0; }
+    return ruler->getEventSelection();
+}
+
+ControlParameter *
+ControlRulerWidget::getControlParameter(void)
+{
+    ControllerEventsRuler *ruler = getActiveRuler();
+    if (!ruler) { return 0; }
+    return ruler->getControlParameter();
+}
+
+// @return the active ruler's parameter situation, or NULL if none.
+// Return is owned by caller.
+// @author Tom Breton (Tehom)
+SelectionSituation *
+ControlRulerWidget::getSituation(void)
+{
+    ControllerEventsRuler *ruler = getActiveRuler();
+    if (!ruler) { return 0; }
+    EventSelection * selection = ruler->getEventSelection();
+    if (!selection) { return 0; }
+    ControlParameter * cp = ruler->getControlParameter();
+    if (!cp) { return 0; }
+    return
+        new SelectionSituation(cp->getType(), selection);
+}
+
 }
 
 #include "ControlRulerWidget.moc"
