@@ -60,7 +60,7 @@ ControllerEventsRuler::ControllerEventsRuler(ViewSegment *segment,
         RulerScale* rulerScale,
         QWidget* parent,
         const ControlParameter *controller,
-        const char* name) //, WFlags f)
+        const char* /* name */) //, WFlags f)
         : ControlRuler(segment, rulerScale, parent), // name, f),
         m_defaultItemWidth(20),
         m_lastDrawnRect(QRectF(0,0,0,0)),
@@ -147,7 +147,7 @@ ControllerEventsRuler::init()
     setMinItemValue(m_controller->getMin());
 
     for (Segment::iterator it = m_segment->begin();
-            it != m_segment->end(); it++) {
+            it != m_segment->end(); ++it) {
         if (isOnThisRuler(*it)) {
             addControlItem(*it);
         }
@@ -166,7 +166,7 @@ void ControllerEventsRuler::paintEvent(QPaintEvent *event)
     ///@TODO Only reconfigure all items if zoom has changed
     if (m_lastDrawnRect != m_pannedRect) {
         EventControlItem *item;
-        for (ControlItemMap::iterator it = m_controlItemMap.begin(); it != m_controlItemMap.end(); it++) {
+        for (ControlItemMap::iterator it = m_controlItemMap.begin(); it != m_controlItemMap.end(); ++it) {
             item = static_cast <EventControlItem *> (it->second);
             item->reconfigure();
         }
@@ -213,7 +213,7 @@ void ControllerEventsRuler::paintEvent(QPaintEvent *event)
         if (mapIt == m_lastVisibleItem) {
             mapIt = m_controlItemMap.end();
         } else {
-            mapIt++;
+            ++mapIt;
         }
     }
     
@@ -427,7 +427,7 @@ ControllerEventsRuler::addControlLine(float x1, float y1, float x2, float y2, bo
     // span of around four bars generated over 15,000 pitch bend events!  That's
     // super duper fine resolution, but it's too much for anything to handle.
     // Let's try to do some sensible thinning without getting too complicated...
-    bool isPitchBend = (m_controller->getType() == Rosegarden::PitchBend::EventType);
+    // bool isPitchBend = (m_controller->getType() == Rosegarden::PitchBend::EventType);
     int thinningHackCounter = 1;
     
     long intermediateValue = originValue;    
