@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2011 the Rosegarden development team.
+    Copyright 2000-2012 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -25,7 +25,7 @@ namespace Rosegarden
 {
 
 class SegmentMapper;
-class MappedSegment;
+class MappedEventBuffer;
 class Segment;
 class RosegardenDocument;
 
@@ -38,7 +38,7 @@ public:
     CompositionMapper(RosegardenDocument *doc);
     ~CompositionMapper();
 
-    MappedSegment *getMappedSegment(Segment *);
+    MappedEventBuffer *getMappedEventBuffer(Segment *);
 
 protected:
     bool segmentModified(Segment *);
@@ -49,6 +49,8 @@ protected:
 
     RosegardenDocument *m_doc;
 
+    // I share ownership of the mappers with instances of
+    // MappedBufMetaIterator
     typedef std::map<Segment*, SegmentMapper *> segmentmappers;
     segmentmappers m_segmentMappers;
 };
