@@ -31,8 +31,29 @@ namespace Rosegarden
 class TriggerSegmentRec;
 class Composition;
  
-// @class InternalSegmentMapper Mapper for an internal segment.
-// @author Tom Breton (Tehom)
+/// Converts (maps) Event objects into MappedEvent objects for a Segment
+/**
+ * @author Tom Breton (Tehom)
+ *
+ * InternalSegmentMapper.  What's in a name?  "Internal" qualifies a
+ * Segment as containing Rosegarden's internal representation of MIDI
+ * notes etc, as opposed to an audio segment.  The term "Mapper" is
+ * used largely for historical reasons, but can be understood as
+ * mapping (converting) Event objects from a Segment into MappedEvent
+ * objects which are ready for playback.  The key mapping routine is
+ * InternalSegmentMapper::fillBuffer().
+ *
+ * This class might be better named MappedMIDISegment as that is what it is
+ * rather than what it does.  It's a more "O-O" name, which in this case feels
+ * better.  Of course, the base class and other related classes would need
+ * to adopt similar names.  The entire MappedEventBuffer hierarchy probably
+ * needs to be examined to see if there are opportunities for simplification
+ * and renaming for increased clarity.
+ *
+ * This is the first part of a two-part process to convert the Event objects
+ * in a Composition into MappedEvent objects that can be sent to ALSA.  For
+ * the second part of this conversion, see MappedBufMetaIterator.
+ */
 class InternalSegmentMapper : public SegmentMapper
 {
     friend class SegmentMapperFactory;
@@ -64,7 +85,7 @@ class InternalSegmentMapper : public SegmentMapper
     };
     // This wants to be a priority_queue but we need to sometimes
     // filter noteoffs so it can't be.
-    typedef std::set<Noteoff, NoteoffCmp>
+    typedef std::multiset<Noteoff, NoteoffCmp>
         NoteoffContainer;
 
     InternalSegmentMapper(RosegardenDocument *doc, Segment *segment);
@@ -74,12 +95,15 @@ class InternalSegmentMapper : public SegmentMapper
     virtual void doInsert(MappedInserterBase &inserter, MappedEvent &evt,
                          RealTime start, bool firstOutput);
 
+    // Return whether the event should be played.
+    virtual bool shouldPlay(MappedEvent *evt, RealTime startTime);
+
     virtual int calculateSize();
 
     int addSize(int size, Segment *);
 
     /// dump all segment data in the file
-    virtual void dump();
+    virtual void fillBuffer();
 
     Instrument *getInstrument(void)
     { return m_channelManager.m_instrument; }
@@ -99,7 +123,7 @@ class InternalSegmentMapper : public SegmentMapper
     IntervalChannelManager m_channelManager;
 
     // Separate storage for triggered events.  This storage, like
-    // original segment, contains just one time thru; logic in "dump"
+    // original segment, contains just one time thru; logic in "fillBuffer"
     // turns it into repeats as needed.
     Segment               *m_triggeredEvents;
     
