@@ -1302,7 +1302,7 @@ SequenceManager::preparePlayback(bool /*forceProgramChanges*/)
 
     // Send the MappedInstruments full information to the Sequencer 
     InstrumentList::iterator it = list.begin();
-    for (; it != list.end(); it++) {
+    for (; it != list.end(); ++it) {
 
         StudioControl::sendMappedInstrument(MappedInstrument(*it));
     }
@@ -1468,7 +1468,7 @@ SequenceManager::applyFiltering(const MappedEventList &mC,
     MappedEventList retMc;
     MappedEventList::const_iterator it = mC.begin();
 
-    for (; it != mC.end(); it++) {
+    for (; it != mC.end(); ++it) {
         if (!((*it)->getType() & filter))
             retMc.insert(new MappedEvent(*it));
     }
@@ -1796,6 +1796,16 @@ void SequenceManager::segmentEndMarkerChanged(const Composition*, Segment *s, bo
     segmentModified(s);
 }
 
+void SequenceManager::segmentInstrumentChanged(Segment *s)
+{
+#ifdef DEBUG_SEQUENCE_MANAGER
+    SEQMAN_DEBUG << "SequenceManager::segmentInstrumentChanged(" << s
+                 << ")" << endl;
+#endif    
+    // Quick and dirty: Redo the whole segment.
+    segmentModified(s);
+}
+
 void SequenceManager::processAddedSegment(Segment* s)
 {
 #ifdef DEBUG_SEQUENCE_MANAGER
