@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2011 the Rosegarden development team.
+    Copyright 2000-2012 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -26,15 +26,15 @@ namespace Rosegarden
 
 class RosegardenDocument;
 
-class SpecialSegmentMapper : public SegmentMapper
+class SpecialSegmentMapper : public MappedEventBuffer
 {
 public:
-    // overrides from SegmentMapper
+    // overrides from MappedEventBuffer.  Exists only for historical
+    // reasons.
     virtual int getSegmentRepeatCount();
 
 protected:
-    SpecialSegmentMapper(RosegardenDocument *doc,
-                         MappedSegment *mapped);
+    SpecialSegmentMapper(RosegardenDocument *doc);
 };
 
 }
