@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2011 the Rosegarden development team.
+    Copyright 2000-2012 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -70,6 +70,9 @@ signals:
     // The menu writes changes directly to the instrument, but it
     // also emits this to let you know something has changed
     void changed();
+private slots:
+    /// Instrument is being destroyed
+    void slotInstrumentGone(void);
 
 private:
     Studio *m_studio;
