@@ -12,20 +12,28 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _ROSEGARDEN_SEQUENCER_THREAD_H_
-#define _ROSEGARDEN_SEQUENCER_THREAD_H_
+#ifndef RG_SEQUENCER_THREAD_H
+#define RG_SEQUENCER_THREAD_H
 
 #include <QThread>
 
 namespace Rosegarden
 {
 
+/// The Sequencer Thread
+/**
+ * This class consists of a single processing loop, run(), which keeps
+ * RosegardenSequencer processing incoming and outgoing MIDI events.
+ *
+ * A single instance of this is created and owned by RosegardenMainWindow.
+ *
+ * @see RosegardenMainWindow::m_sequencerThread
+ * @see RosegardenMainWindow::launchSequencer()
+ */
 class SequencerThread : public QThread
 {
-public:
-    
-
 protected:
+    /// The sequencer thread's processing loop.
     virtual void run();
 };
 
